@@ -1,21 +1,20 @@
-;;; dectalk-voices.el --- Define various device independent voices in terms of Dectalk codes  -*- lexical-binding: t; -*-
+;;; dectalk-voices.el --- Dectalk Voice  Codes-*- lexical-binding: t; -*-
 ;;
 ;; $Author: tv.raman.tv $
 ;; Description:  Module to set up Dectalk voices and personalities
 ;; Keywords: Voice, Personality, Dectalk
-;;{{{  LCD Archive entry:
+;;;   LCD Archive entry:
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ |
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman
 ;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;; All Rights Reserved.
 ;; 
@@ -33,30 +32,27 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  Introduction:
 
 ;;; Commentary:
 ;; This module defines the various voices used in voice-lock mode.
 ;; This module is Dectalk specific.
 ;;; Code:
 
-;;}}}
-;;{{{ required modules
+;;  required modules
 
-(require 'cl-lib)
+(eval-when-compile (require 'cl-lib))
 (require 'emacspeak-preamble)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 
-;;}}}
-;;{{{ Customizations:
+;;;  Customizations:
 
 (defcustom dectalk-default-speech-rate 225
-  "Default speech rate . "
+  "Default speech rate for DECTalk engines. "
   :group 'tts
   :type 'integer
   :set #'(lambda(sym val)
@@ -64,8 +60,7 @@
            (when (string-match "dtk" dtk-program)
              (setq-default dtk-speech-rate val))))
 
-;;}}}
-;;{{{  Top-level TTS  switcher
+;;;   Top-level TTS  switcher
 
 ;;;###autoload
 (defun dectalk ()
@@ -76,18 +71,25 @@
   (dtk-select-server "dtk-exp")
   (dtk-initialize))
 
-;;}}}
-;;{{{ Forward declarations:
+;;;###autoload
+(defun dectalk-soft ()
+  "Software Dectalk TTS."
+  (interactive)
+  (let ((coding-system-for-write  'iso-8859-1))
+    (dectalk-configure-tts)
+    (ems--fastload "voice-defs")
+    (dtk-select-server "dtk-soft")
+    (dtk-initialize)
+    (dtk-set-rate dectalk-default-speech-rate 'global)))
+
+;;;  Forward declarations:
 
 ;; From dtk-speak.el:
 
-(defvar tts-default-speech-rate)
-
 (defvar dtk-speech-rate-step)
 (defvar dtk-speech-rate-base)
 
-;;}}}
-;;{{{  voice table
+;;;   voice table
 
 (defvar dectalk-default-voice-string ""
   "Dectalk string for  default voice --set to be a no-op.")
@@ -114,16 +116,14 @@
   (cl-declare (special dectalk-voice-table))
   (gethash name dectalk-voice-table))
 
-;;}}}
-;;{{{ voice definitions
+;;;  voice definitions
 
 ;; the nine predefined voices:
 (dectalk-define-voice 'paul "[:np ]")
 
-;;}}}
-;;{{{  Mapping css parameters to Dectalk codes
+;;;   Mapping css parameters to Dectalk codes
 
-;;{{{ voice family codes
+;;;  voice family codes
 
 (defvar dectalk-family-table nil
   "Association list of Dectalk voice names and control codes.")
@@ -147,8 +147,7 @@
 
 (dectalk-set-family-code 'paul ":np")
 
-;;}}}
-;;{{{  hash table for mapping families to their dimensions
+;;;   hash table for mapping families to their dimensions
 
 (defvar dectalk-css-code-tables (make-hash-table)
   "Hash table holding vectors of Dectalk codes. ")
@@ -167,8 +166,7 @@ and TABLE gives the values along that dimension."
   (let ((key (intern (format "%s-%s" family dimension))))
     (gethash key dectalk-css-code-tables)))
 
-;;}}}
-;;{{{  average pitch
+;;;   average pitch
 
 ;; Average pitch for standard male voice is 122hz --this is mapped to
 ;; a setting of 5.
@@ -177,7 +175,7 @@ and TABLE gives the values along that dimension."
 ;; We change parameter head-size in conjunction with average pitch to
 ;; produce a more natural change on the Dectalk.
 
-;;{{{  paul average pitch
+;;;   paul average pitch
 
 (let ((table (make-vector 10 "")))
   (mapc
@@ -201,10 +199,6 @@ and TABLE gives the values along that dimension."
      ))
   (dectalk-css-set-code-table 'paul 'average-pitch table))
 
-;;}}}
-
-;;}}}
-
 (defun dectalk-get-average-pitch-code (value family)
   "Get  AVERAGE-PITCH for  VALUE and  FAMILY."
   (or family (setq family 'paul))
@@ -213,8 +207,7 @@ and TABLE gives the values along that dimension."
             value)
     ""))
 
-;;}}}
-;;{{{  pitch range
+;;;   pitch range
 
 ;;  Standard pitch range is 100 and is  mapped to
 ;; a setting of 5.
@@ -222,7 +215,7 @@ and TABLE gives the values along that dimension."
 ;; produces a highly animated voice.
 ;; Additionally, we also set the assertiveness of the voice so the
 ;; voice is less assertive at lower pitch ranges.
-;;{{{  paul pitch range
+;;;   paul pitch range
 
 (let ((table (make-vector 10 "")))
   (mapc
@@ -246,8 +239,6 @@ and TABLE gives the values along that dimension."
      ))
   (dectalk-css-set-code-table 'paul 'pitch-range table))
 
-;;}}}
-
 (defun dectalk-get-pitch-range-code (value family)
   "Get pitch-range code for  VALUE and FAMILY."
   (or family (setq family 'paul))
@@ -256,8 +247,7 @@ and TABLE gives the values along that dimension."
             value)
     ""))
 
-;;}}}
-;;{{{  stress
+;;;   stress
 
 ;; On the Dectalk we vary four parameters
 ;; The hat rise which controls the overall shape of the F0 contour
@@ -268,7 +258,7 @@ and TABLE gives the values along that dimension."
 ;; and the quickness --a parameter that controls whether the final
 ;; frequency targets are completely achieved in the phonetic
 ;; transitions.
-;;{{{  paul stress
+;;;   paul stress
 
 (let ((table (make-vector 10 "")))
   (mapc
@@ -294,8 +284,6 @@ and TABLE gives the values along that dimension."
      ))
   (dectalk-css-set-code-table 'paul 'stress table))
 
-;;}}}
-
 (defun dectalk-get-stress-code (value family)
   (or family (setq family 'paul))
   (if value
@@ -303,13 +291,12 @@ and TABLE gives the values along that dimension."
             value)
     ""))
 
-;;}}}
-;;{{{  richness
+;;;   richness
 
 ;; Smoothness and richness vary inversely.
 ;; a  maximally smooth voice produces a quieter effect
 ;; a rich voice is "bright" in contrast.
-;;{{{  paul richness
+;;;   paul richness
 
 (let ((table (make-vector 10 "")))
   (mapc
@@ -332,8 +319,6 @@ and TABLE gives the values along that dimension."
      ))
   (dectalk-css-set-code-table 'paul 'richness table))
 
-;;}}}
-
 (defun dectalk-get-richness-code (value family)
   (or family (setq family 'paul))
   (if value
@@ -341,29 +326,30 @@ and TABLE gives the values along that dimension."
             value)
     ""))
 
-;;}}}
-;;{{{  dectalk-define-voice-from-speech-style
+;;;   dectalk-define-voice-from-speech-style
 
 (defun dectalk-define-voice-from-speech-style (name style)
   "Define NAME to be a Dectalk voice as specified by settings in STYLE."
   (let* ((family(acss-family style))
          (command
-          (concat "["
-                  (dectalk-get-family-code family)
-                  (when (or (acss-average-pitch style)
-                            (acss-pitch-range style)
-                            (acss-stress style)
-                            (acss-richness style))
-                    (concat " :dv "
-                            (dectalk-get-average-pitch-code (acss-average-pitch style) family)
-                            (dectalk-get-pitch-range-code (acss-pitch-range style) family)
-                            (dectalk-get-stress-code (acss-stress style) family)
-                            (dectalk-get-richness-code (acss-richness style) family)))
-                  "]")))
+          (concat
+           "["
+           (dectalk-get-family-code family)
+           (when (or (acss-average-pitch style)
+                     (acss-pitch-range style)
+                     (acss-stress style)
+                     (acss-richness style))
+             (concat
+              " :dv "
+              (dectalk-get-average-pitch-code
+               (acss-average-pitch style) family)
+              (dectalk-get-pitch-range-code (acss-pitch-range style) family)
+              (dectalk-get-stress-code (acss-stress style) family)
+              (dectalk-get-richness-code (acss-richness style) family)))
+           "]")))
     (dectalk-define-voice name command)))
 
-;;}}}
-;;{{{ configurater
+;;;  configurater
 
 ;;;###autoload
 (defun dectalk-configure-tts ()
@@ -373,21 +359,18 @@ and TABLE gives the values along that dimension."
   (setq tts-default-voice 'paul)
   (fset 'tts-voice-defined-p 'dectalk-voice-defined-p)
   (fset 'tts-get-voice-command 'dectalk-get-voice-command)
-  (fset 'tts-define-voice-from-speech-style 'dectalk-define-voice-from-speech-style)
+  (fset
+   'tts-define-voice-from-speech-style 'dectalk-define-voice-from-speech-style)
   (setq tts-default-speech-rate dectalk-default-speech-rate)
   (set-default 'tts-default-speech-rate dectalk-default-speech-rate)
   (setq dtk-speech-rate-step 50
         dtk-speech-rate-base 150)
   (setq-default dtk-speech-rate-step 50
-                dtk-speech-rate-base 150))
-
-;;}}}
+                dtk-speech-rate-base 150)
+  (dtk-set-character-scale 1.5 'default)
+  (setq dtk-handle-unicode t)
+  (dtk-unicode-update-untouched-charsets
+   '(ascii latin-iso8859-1 latin-iso8859-15 latin-iso8859-9 eight-bit-graphic)))
 
 (provide 'dectalk-voices)
-;;{{{  emacs local variables
 
-;; local variables:
-;; folded-file: t
-;; end:
-
-;;}}}
