@@ -1,21 +1,20 @@
-;;; emacspeak-calc.el --- Speech enable the Emacs Calculator -- a powerful symbolic algebra system  -*- lexical-binding: t; -*-
+;;; emacspeak-calc.el --- Speech enable Calc   -*- lexical-binding: t; -*-
 ;;
 ;; $Author: tv.raman.tv $ 
 ;;; Description: 
 ;;; Keywords:
-;;{{{  LCD Archive entry: 
+;;;   LCD Archive entry: 
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ | 
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman 
 ;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;; All Rights Reserved. 
 ;; 
@@ -33,11 +32,11 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 
-;;{{{  Introduction:
+
 ;;; Commentary:
 ;; This module extends the Emacs Calculator.
 ;; Extensions are minimal.
@@ -45,26 +44,24 @@
 ;; And use an after advice on this function
 ;; To fix all of calc's interactive functions
 ;;; Code:
-;;}}}
-;;{{{ required modules
+
+;;  required modules
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
-;;}}}
-;;{{{  advice calc interaction 
+;;;   advice calc interaction 
 (defadvice calc-dispatch (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'open-object)))
+    (emacspeak-icon 'open-object)))
 
 (defadvice calc-quit (after emacspeak pre act comp)
   "Announce the buffer that becomes current when calc is quit."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'close-object)
+    (emacspeak-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
-;;}}}
-;;{{{  speak output 
+;;;   speak output 
 
 (defadvice calc-call-last-kbd-macro (around emacspeak pre act comp)
   "Speak."
@@ -73,7 +70,7 @@
     (ems-with-messages-silenced ad-do-it)
     (tts-with-punctuations 'all
                            (emacspeak-read-previous-line))
-    (emacspeak-auditory-icon 'task-done))
+    (emacspeak-icon 'task-done))
    (t ad-do-it))
   ad-return-value)
 
@@ -83,20 +80,13 @@
   (tts-with-punctuations
    'all
    (emacspeak-read-previous-line)
-   (emacspeak-auditory-icon 'select-object))
+   (emacspeak-icon 'select-object))
   ad-return-value)
 
 (defadvice  calc-trail-here (after emacspeak pre act comp)
   "Speak previous line of output."
   (emacspeak-speak-line)
-  (emacspeak-auditory-icon 'select-object))
+  (emacspeak-icon 'select-object))
 
-;;}}}
 (provide 'emacspeak-calc)
-;;{{{  emacs local variables 
 
-;; local variables:
-;; folded-file: t
-;; end: 
-
-;;}}}
