@@ -2,18 +2,17 @@
 ;; $Author: tv.raman.tv $
 ;; Description:  Speech-enable COMINT An Emacs Interface to comint
 ;; Keywords: Emacspeak,  Audio Desktop comint
-;;{{{  LCD Archive entry:
+;;;   LCD Archive entry:
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ |
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
+;;;   Copyright:
 
 ;; Copyright (C) 1995 -- 2007, 2019, T. V. Raman
 ;; All Rights Reserved.
@@ -32,12 +31,11 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  introduction
 
 ;;; Commentary:
 
@@ -47,40 +45,24 @@
 
 ;;; Code:
 
-;;}}}
-;;{{{  Required modules
+;;   Required modules:
 
-(require 'cl-lib)
+(eval-when-compile (require 'cl-lib))
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'comint)
 (require 'shell)
 
-;;}}}
-;;{{{ comint
-
-(defun emacspeak-completion-pick-completion ()
-  "Pick completion."
-  (interactive)
-  (cl-declare (special completion-reference-buffer))
-  (let ((completion-ignore-case t))
-    (choose-completion-string (emacspeak-get-current-completion) completion-reference-buffer))
-  (emacspeak-auditory-icon 'select-object)
-  (cond
-   ((not (or
-          (window-minibuffer-p)
-          (one-window-p)
-          (window-dedicated-p (selected-window))))
-    (delete-window)
-    (bury-buffer "*Completions*")
-    (other-window 1))
-   (t
-    (kill-buffer "*Completions*")))
-  (emacspeak-speak-line))
-
-(defcustom emacspeak-comint-autospeak t
+;;;  comint
+;;;###autoload
+(defcustom emacspeak-comint-autospeak nil
   "Speak comint output.
-Use \\[emacspeak-toggle-comint-autospeak] to toggle this setting."
+Use \\[emacspeak-toggle-comint-autospeak] to toggle this
+setting. Do not set this globally. Also see custom option
+`emacspeak-wizards-project-shells' for starting up
+project-specific shells that have autospeak turned on. The
+default is intentionally nil, since this option should only be
+turned on where needed."
   :group 'emacspeak-speak
   :type 'boolean)
 
@@ -95,12 +77,13 @@ Interactive PREFIX arg means toggle  global default value. "
     (setq-default
      emacspeak-comint-autospeak
      (not (default-value 'emacspeak-comint-autospeak)))
-    (setq emacspeak-comint-autospeak (default-value 'emacspeak-comint-autospeak)))
+    (setq emacspeak-comint-autospeak
+          (default-value 'emacspeak-comint-autospeak)))
    (t (make-local-variable 'emacspeak-comint-autospeak)
       (setq emacspeak-comint-autospeak (not emacspeak-comint-autospeak))))
   (when (called-interactively-p 'interactive)
-    (emacspeak-auditory-icon (if emacspeak-comint-autospeak "on" "off"))
-    (dtk-speak-and-echo
+    (emacspeak-icon (if emacspeak-comint-autospeak 'on 'off))
+    (message
      (format "Turned emacspeak-comint-autospeak %s  %s."
              (if emacspeak-comint-autospeak "on" "off")
              (if prefix "" " locally")))))
@@ -124,43 +107,71 @@ buffer is not current or its window live.")
 
 (make-variable-buffer-local 'emacspeak-comint-output-monitor)
 
-;;;###autoload (autoload 'emacspeak-toggle-comint-output-monitor "emacspeak-comint" t)
+;;;###autoload
 (ems-generate-switcher 'emacspeak-toggle-comint-output-monitor
                        'emacspeak-comint-output-monitor
                        "Toggle  Emacspeak comint monitor.
 Interactive PREFIX arg means toggle the global default value. ")
 
-;;;###autoload
+
 (defun emacspeak-comint-speech-setup ()
   "Speech setup."
-  (cl-declare (special comint-mode-map
-                       header-line-format emacspeak-use-header-line))
-  ;; Experimental: discard undo info in comint:
-  (setq buffer-undo-list t)
+  (cl-declare (special
+               emacspeak-speak-time-brief-format
+               comint-mode-map
+               emacspeak-pronounce-sha-checksum-pattern
+               emacspeak-pronounce-date-mm-dd-yyyy-pattern
+               header-line-format emacspeak-use-header-line))
+  (setq buffer-undo-list  t)
+  (define-key comint-mode-map "\C-o" 'switch-to-completions)
   (when emacspeak-use-header-line
     (setq
      header-line-format
      '((:eval
         (concat
-         (abbreviate-file-name default-directory)
+         (format-time-string emacspeak-speak-time-brief-format)
          (propertize (buffer-name) 'personality voice-annotate)
-         (when emacspeak-comint-autospeak
+         (abbreviate-file-name default-directory)
+         (when (ems--comint-autospeak)
            (propertize "Autospeak" 'personality voice-lighten))
          (when (> (length (window-list)) 1)
            (format "%s" (length (window-list)))))))))
   (dtk-set-punctuations 'all)
-  (define-key comint-mode-map "\C-o" 'switch-to-completions)
+  (emacspeak-pronounce-add-dictionary-entry
+   'comint-mode
+   emacspeak-pronounce-uuid-pattern
+   (cons 're-search-forward
+         'emacspeak-pronounce-uuid))
+  (emacspeak-pronounce-add-dictionary-entry
+   'comint-mode
+   emacspeak-pronounce-sha-checksum-pattern
+   (cons 're-search-forward
+         'emacspeak-pronounce-sha-checksum))
+  (emacspeak-pronounce-add-dictionary-entry
+   'comint-mode
+   emacspeak-pronounce-date-mm-dd-yyyy-pattern
+   (cons 're-search-forward
+         'emacspeak-pronounce-mm-dd-yyyy-date))
+  (emacspeak-pronounce-add-dictionary-entry
+   'comint-mode
+   emacspeak-pronounce-date-yyyy-mm-dd-pattern
+   (cons 're-search-forward
+         'emacspeak-pronounce-yyyy-mm-dd-date))
+  (emacspeak-pronounce-add-dictionary-entry
+   'comint-mode
+   emacspeak-pronounce-rfc-3339-datetime-pattern
+   (cons 're-search-forward
+         'emacspeak-pronounce-decode-rfc-3339-datetime))
   (emacspeak-pronounce-refresh-pronunciations))
 
 (add-hook 'comint-mode-hook 'emacspeak-comint-speech-setup)
 
-;;}}}
-;;{{{ Advice comint:
+;;;  Advice comint:
 
 (defadvice comint-delete-output (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'delete-object)
+    (emacspeak-icon 'delete-object)
     (emacspeak-speak-line)))
 (cl-loop
  for f in
@@ -172,13 +183,13 @@ Interactive PREFIX arg means toggle the global default value. ")
      (when (ems-interactive-p)
        (save-excursion
          (comint-bol-or-process-mark)
-         (emacspeak-auditory-icon 'select-object)
+         (emacspeak-icon 'select-object)
          (emacspeak-speak-line 1))))))
 
 (defadvice comint-clear-buffer (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'delete-object)
+    (emacspeak-icon 'delete-object)
     (emacspeak-speak-line)))
 
 (defadvice comint-magic-space (around emacspeak pre act comp)
@@ -196,7 +207,7 @@ Interactive PREFIX arg means toggle the global default value. ")
            (forward-word -1)
            (emacspeak-speak-word)))
         (t
-         (emacspeak-auditory-icon 'complete)
+         (emacspeak-icon 'complete)
          (emacspeak-speak-region
           (comint-line-beginning-position) (point)))))))
    (t ad-do-it))
@@ -209,7 +220,7 @@ Interactive PREFIX arg means toggle the global default value. ")
     (let ((orig (point)))
       ad-do-it
       (emacspeak-speak-region orig (point))
-      (emacspeak-auditory-icon 'yank-object)))
+      (emacspeak-icon 'yank-object)))
    (t ad-do-it))
   ad-return-value)
 
@@ -226,21 +237,7 @@ Interactive PREFIX arg means toggle the global default value. ")
  '(
    (comint-highlight-prompt voice-lighten-extra)
    (comint-highlight-input voice-bolden-medium)))
-(cl-declaim (special emacspeak-pronounce-sha-checksum-pattern))
 
-(emacspeak-pronounce-add-dictionary-entry
- 'comint-mode
- emacspeak-pronounce-sha-checksum-pattern
- (cons 're-search-forward
-       'emacspeak-pronounce-sha-checksum))
-
-(cl-declaim (special emacspeak-pronounce-uuid-pattern))
-
-(emacspeak-pronounce-add-dictionary-entry
- 'comint-mode
- emacspeak-pronounce-uuid-pattern
- (cons 're-search-forward
-       'emacspeak-pronounce-uuid))
 (cl-loop
  for mode in
  '(conf-space-mode conf-unix-mode conf-mode)
@@ -251,8 +248,6 @@ Interactive PREFIX arg means toggle the global default value. ")
   (cons 're-search-forward
         'emacspeak-pronounce-uuid)))
 
-(add-hook 'shell-mode-hook 'emacspeak-pronounce-refresh-pronunciations)
-
 (defadvice shell-dirstack-message (around emacspeak pre act comp)
   "Silence messages"
   (ems-with-messages-silenced
@@ -281,7 +276,7 @@ Interactive PREFIX arg means toggle the global default value. ")
   (when (ems-interactive-p)
     (save-excursion
       (comint-bol)
-      (emacspeak-auditory-icon 'select-object)
+      (emacspeak-icon 'select-object)
       (emacspeak-speak-line 1))))
 (cl-loop
  for f in
@@ -296,27 +291,27 @@ Interactive PREFIX arg means toggle the global default value. ")
        (save-excursion
          (goto-char (comint-line-beginning-position))
          (emacspeak-speak-line 1))
-       (emacspeak-auditory-icon 'select-object)))))
+       (emacspeak-icon 'select-object)))))
 
 (defadvice shell-forward-command (after emacspeak pre act comp)
   "Speak  line."
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line)
-      (emacspeak-auditory-icon 'item))))
+      (emacspeak-icon 'item))))
 
 (defadvice shell-backward-command (after emacspeak pre act comp)
   "Speak  line."
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line)
-      (emacspeak-auditory-icon 'item))))
+      (emacspeak-icon 'item))))
 
 (defadvice comint-show-output (after emacspeak pre act comp)
   "Speak  line."
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
-      (emacspeak-auditory-icon 'large-movement)
+      (emacspeak-icon 'large-movement)
       (emacspeak-speak-region (point) (mark)))))
 
 (defadvice comint-show-maximum-output (after emacspeak pre act comp)
@@ -324,19 +319,19 @@ Interactive PREFIX arg means toggle the global default value. ")
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line)
-      (emacspeak-auditory-icon 'scroll))))
+      (emacspeak-icon 'scroll))))
 
 (defadvice comint-bol-or-process-mark (after emacspeak pre act comp)
   "Speak line."
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line)
-      (emacspeak-auditory-icon 'select-object))))
+      (emacspeak-icon 'select-object))))
 
 (defadvice comint-copy-old-input (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'yank-object)
+    (emacspeak-icon 'yank-object)
     (emacspeak-speak-line)))
 
 (defadvice comint-output-filter (around emacspeak pre act comp)
@@ -353,16 +348,17 @@ instead, always play an auditory icon when the shell prompt is displayed."
            (not  (string-match "^\r" output)) ;;; skip invisible output 
            comint-last-output-start
            (or monitor (eq (window-buffer) buffer)))
-        (let
-            ((prompt-p
-              (save-excursion
-                (goto-char comint-last-output-start)
-                (or (looking-at shell-prompt-pattern)
-                    (looking-at comint-prompt-regexp)))))
+        (let ((prompt-p
+               (save-excursion
+                 (goto-char comint-last-output-start)
+                 (or (looking-at shell-prompt-pattern)
+                     (looking-at comint-prompt-regexp)))))
           (cond
            ( (and emacspeak-comint-autospeak (not prompt-p))
              (dtk-speak output))
-           ( prompt-p (when emacspeak-comint-autospeak (emacspeak-auditory-icon 'item))))))
+           ( prompt-p
+             (when emacspeak-comint-autospeak
+               (emacspeak-icon 'item))))))
       ad-return-value)))
 
 (defadvice comint-dynamic-list-completions (around emacspeak pre act comp)
@@ -389,7 +385,7 @@ instead, always play an auditory icon when the shell prompt is displayed."
        (if (> (point) prior)
            (tts-with-punctuations
             'all
-            (emacspeak-auditory-icon 'complete)
+            (emacspeak-icon 'complete)
             (dtk-speak (buffer-substring prior (point))))
          (emacspeak-speak-completions-if-available)))))
    (t ad-do-it))
@@ -403,7 +399,7 @@ instead, always play an auditory icon when the shell prompt is displayed."
      (save-excursion
        (goto-char (comint-line-beginning-position))
        (emacspeak-speak-line 1)))
-    (emacspeak-auditory-icon 'item)))
+    (emacspeak-icon 'item)))
 
 (defadvice comint-next-matching-input (after emacspeak pre act comp)
   "Speak line."
@@ -413,7 +409,7 @@ instead, always play an auditory icon when the shell prompt is displayed."
      (save-excursion
        (goto-char (comint-line-beginning-position))
        (emacspeak-speak-line 1)))
-    (emacspeak-auditory-icon 'item)))
+    (emacspeak-icon 'item)))
 
 (defadvice comint-previous-input (after emacspeak pre act comp)
   "Speak line."
@@ -423,7 +419,7 @@ instead, always play an auditory icon when the shell prompt is displayed."
      (save-excursion
        (goto-char (comint-line-beginning-position))
        (emacspeak-speak-line 1)))
-    (emacspeak-auditory-icon 'item)))
+    (emacspeak-icon 'item)))
 
 (defadvice comint-previous-matching-input (after emacspeak pre act comp)
   "Speak line."
@@ -433,18 +429,18 @@ instead, always play an auditory icon when the shell prompt is displayed."
      (save-excursion
        (goto-char (comint-line-beginning-position))
        (emacspeak-speak-line 1)))
-    (emacspeak-auditory-icon 'item)))
+    (emacspeak-icon 'item)))
 
 (defadvice comint-send-input (after emacspeak pre act comp)
   "Flush any ongoing speech."
   (when (ems-interactive-p)
-    (dtk-stop)
-    (emacspeak-auditory-icon 'progress)))
+    (dtk-stop 'all)
+    (emacspeak-icon 'more)))
 
 (defadvice comint-previous-prompt (after emacspeak pre act comp)
   "Speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'item)
+    (emacspeak-icon 'item)
     (if (eolp)
         (emacspeak-speak-line)
       (emacspeak-speak-line 1))))
@@ -452,7 +448,7 @@ instead, always play an auditory icon when the shell prompt is displayed."
 (defadvice comint-next-prompt (after emacspeak pre act comp)
   "Speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'item)
+    (emacspeak-icon 'item)
     (if (eolp)
         (emacspeak-speak-line)
       (emacspeak-speak-line 1))))
@@ -460,7 +456,7 @@ instead, always play an auditory icon when the shell prompt is displayed."
 (defadvice comint-get-next-from-history (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'item)
+    (emacspeak-icon 'item)
     (save-excursion
       (comint-bol)
       (emacspeak-speak-line 1))))
@@ -487,7 +483,7 @@ instead, always play an auditory icon when the shell prompt is displayed."
           (forward-line 3)
           (while (search-backward "completion" nil 'move)
             (replace-match "history reference")))
-        (emacspeak-auditory-icon 'help)
+        (emacspeak-icon 'help)
         (next-completion 1)
         (dtk-speak (emacspeak-get-current-completion)))))
    (t ad-do-it))
@@ -496,7 +492,7 @@ instead, always play an auditory icon when the shell prompt is displayed."
 (defadvice comint-kill-output (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'delete-object)
+    (emacspeak-icon 'delete-object)
     (message "Nuked output of last command ")))
 
 (defadvice comint-quit-subjob (after emacspeak pre act comp)
@@ -517,18 +513,18 @@ instead, always play an auditory icon when the shell prompt is displayed."
 (defadvice comint-kill-input (before emacspeak pre act comp)
   "Speak."
   (when (ems-interactive-p)
+    (emacspeak-icon 'delete-object)
     (let ((pmark (process-mark (get-buffer-process (current-buffer)))))
       (when (> (point) (marker-position pmark))
-        (emacspeak-auditory-icon 'delete-object)
         (emacspeak-speak-region pmark (point))))))
 
-(defadvice comint-dynamic-list-filename-completions (after emacspeak pre act comp)
+(defadvice comint-dynamic-list-filename-completions
+    (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
     (emacspeak-speak-completions-if-available)))
 
-;;}}}
-;;{{{dirtrack-procfs:
+;;; dirtrack-procfs:
 
 (declare-function shell-dirtrack-mode "shell" (&optional arg))
 ;; Directory tracking for shell buffers on  systems that have  /proc
@@ -574,12 +570,27 @@ Shell-Dirtrack mode; turning it off does not re-enable it."
 (when (file-exists-p "/proc")
   (add-hook 'shell-mode-hook 'dirtrack-procfs-mode))
 
-;;}}}
+;;; zoxide:
+;;; Inspired by zoxide.el
+(defconst emacspeak-comint-zoxide (executable-find "zoxide")
+  "Zoxide Executable")
+;;;###autoload
+(defun emacspeak-zoxide (q)
+  "Query zoxide  and launch dired.
+Shell Utility zoxide --- implemented in Rust --- lets you jump to
+directories that are used often. "
+  (interactive "sZoxide:")
+  (if-let
+      ((z emacspeak-comint-zoxide)
+       (target
+        (with-temp-buffer; match found here if process returns 0
+          (if (= 0 (call-process z nil t nil "query" q))
+              (string-trim (buffer-string))))))
+      (funcall-interactively #'dired  target)
+    (unless z (error "Install zoxide"))
+    (unless target (error "No Match"))))
+
+(provide 'emacspeak-wizards)
 (provide 'emacspeak-comint)
-;;{{{ end of file
+;;;  end of file
 
-;; local variables:
-;; folded-file: t
-;; end:
-
-;;}}}
