@@ -1,19 +1,18 @@
-;;; emacspeak-dismal.el --- Speech enable Dismal -- An Emacs Spreadsheet program  -*- lexical-binding: t; -*-
+;;; emacspeak-dismal.el --- Speech enable Dismal -*- lexical-binding: t; -*-
 ;; Description: spread sheet extension
 ;; Keywords:emacspeak, audio interface to emacs spread sheets
-;;{{{  LCD Archive entry: 
+;;;   LCD Archive entry: 
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ | 
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman 
 ;; Copyright (c) 1995 by T. V. Raman  
 ;; All Rights Reserved. 
 ;; 
@@ -31,22 +30,21 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
-;;{{{  Introduction
+;;;   Introduction
 
 ;; emacspeak extensions to the dismal spreadsheet. 
 ;; Dismal can be found at ftp://cs.nyu.edu/pub/local/fox/dismal
 ;;; Code:
 
-;;}}}
-;;{{{  requires 
-(require 'cl-lib)
+;;;   requires 
+(eval-when-compile (require 'cl-lib))
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-;;}}}
-;;{{{ Forward Decls:
+
+;;;  Forward Decls:
 
 (declare-function dismal-get-val "ext:dismal" (r c))
 (declare-function  dismal-convert-cellexpr-to-string "dismal" (sexp))
@@ -58,8 +56,7 @@
 (declare-function  dis-backward-column "dismal" (cols))
 (declare-function dis-recalculate-matrix "dismal" nil)
 
-;;}}}
-;;{{{  helper functions:
+;;;   helper functions:
 
 ;; return cell value as a string
 
@@ -85,8 +82,7 @@
   (dismal-convert-cellexpr-to-string
    (dismal-get-exp 0  dismal-current-col)))
 
-;;}}}
-;;{{{  Additional interactive commands
+;;;   Additional interactive commands
 
 (defun emacspeak-dismal-display-cell-expression ()
   "Display the expression in the message area"
@@ -149,8 +145,7 @@ The `column header' is the entry in row 0."
   (dis-backward-column cols)
   (emacspeak-dismal-col-summarize))
 
-;;}}}
-;;{{{  Intelligent summaries
+;;;   Intelligent summaries
 
 (defvar emacspeak-dismal-sheet-summarizer-list nil
   "Specifies how the entire sheet  should be summarized. ")
@@ -198,9 +193,10 @@ emacspeak-dismal-row-summarizer-list"
                          (format "%s"
                                  (emacspeak-dismal-cell-value
                                   dismal-current-row token)))
-                   (put-text-property  0   (length value)
-                                       'personality  emacspeak-dismal-value-personality 
-                                       value)
+                   (put-text-property
+                    0   (length value)
+                    'personality  emacspeak-dismal-value-personality 
+                    value)
                    value)
                   ((and (listp token)
                         (numberp (cl-first token))
@@ -210,9 +206,10 @@ emacspeak-dismal-row-summarizer-list"
                                  (emacspeak-dismal-cell-value
                                   (cl-first token)
                                   (cl-second token))))
-                   (put-text-property 0   (length value)
-                                      'personality emacspeak-dismal-value-personality 
-                                      value)
+                   (put-text-property
+                    0   (length value)
+                    'personality emacspeak-dismal-value-personality 
+                    value)
                    value)
                   (t  (format "%s" token)))))
            emacspeak-dismal-row-summarizer-list 
@@ -232,36 +229,37 @@ emacspeak-dismal-col-summarizer-list"
           (read-minibuffer "Specify summarizer as a vector:
 " "[")))
   (let ((summary nil))
-    (setq summary 
-          (mapconcat
-           #'(lambda (token)
-               (let ((value nil))
-                 (cond
-                  ((stringp token) token)
-                  ((numberp token)
-                   (setq value
-                         (format "%s"
-                                 (emacspeak-dismal-cell-value token
-                                                              dismal-current-col)))
-                   (put-text-property 0 (length value)
-                                      'personality
-                                      emacspeak-dismal-value-personality value)
-                   value)
-                  ((and (listp token)
-                        (numberp (cl-first token))
-                        (numberp (cl-second token)))
-                   (setq value
-                         (format "%s"
-                                 (emacspeak-dismal-cell-value
-                                  (cl-first token)
-                                  (cl-second token))))
-                   (put-text-property 0 (length value)
-                                      'personality
-                                      emacspeak-dismal-value-personality value)
-                   value)
-                  (t  (format "%s" token)))))
-           emacspeak-dismal-col-summarizer-list 
-           " "))
+    (setq
+     summary 
+     (mapconcat
+      #'(lambda (token)
+          (let ((value nil))
+            (cond
+             ((stringp token) token)
+             ((numberp token)
+              (setq value
+                    (format
+                     "%s"
+                     (emacspeak-dismal-cell-value token dismal-current-col)))
+              (put-text-property 0 (length value)
+                                 'personality
+                                 emacspeak-dismal-value-personality value)
+              value)
+             ((and (listp token)
+                   (numberp (cl-first token))
+                   (numberp (cl-second token)))
+              (setq value
+                    (format "%s"
+                            (emacspeak-dismal-cell-value
+                             (cl-first token)
+                             (cl-second token))))
+              (put-text-property 0 (length value)
+                                 'personality
+                                 emacspeak-dismal-value-personality value)
+              value)
+             (t  (format "%s" token)))))
+      emacspeak-dismal-col-summarizer-list 
+      " "))
     (dtk-speak summary)))
 
 (defun emacspeak-dismal-sheet-summarize  ()
@@ -317,28 +315,28 @@ emacspeak-dismal-sheet-summarizer-list"
          (format "%S"
                  (or emacspeak-dismal-sheet-summarizer-list  "[")))))
 
-;;}}}
-;;{{{  key bindings
+;;;   key bindings
 
 ;; record emacspeak stat that we want dismal to save
 (defvar emacspeak-dismal-already-customized-dismal nil
   "Records if we have customized dismal.
 Checked by emacspeak specific dis-mode-hooks entry.")
 
-(add-hook 'dis-mode-hooks
-          #'(lambda nil
-              (cl-declare (special dismal-saved-variables dismal-map))
-              (define-key dismal-map (concat emacspeak-prefix "e")
-                          'dis-last-column)
-              (define-key dismal-map emacspeak-prefix 'emacspeak-prefix-command)
-              (unless emacspeak-dismal-already-customized-dismal
-                (setq emacspeak-dismal-already-customized-dismal t)
-                (push 'emacspeak-dismal-sheet-summarizer-list
-                      dismal-saved-variables)
-                (push 'emacspeak-dismal-row-summarizer-list
-                      dismal-saved-variables)
-                (push 'emacspeak-dismal-col-summarizer-list
-                      dismal-saved-variables))))
+(add-hook
+ 'dis-mode-hooks
+ #'(lambda nil
+     (cl-declare (special dismal-saved-variables dismal-map))
+     (define-key dismal-map (concat emacspeak-prefix "e")
+                 'dis-last-column)
+     (define-key dismal-map emacspeak-prefix 'emacspeak-keymap)
+     (unless emacspeak-dismal-already-customized-dismal
+       (setq emacspeak-dismal-already-customized-dismal t)
+       (push 'emacspeak-dismal-sheet-summarizer-list
+             dismal-saved-variables)
+       (push 'emacspeak-dismal-row-summarizer-list
+             dismal-saved-variables)
+       (push 'emacspeak-dismal-col-summarizer-list
+             dismal-saved-variables))))
 
 (add-hook
  'dis-mode-hooks
@@ -346,7 +344,7 @@ Checked by emacspeak specific dis-mode-hooks entry.")
      (cl-declare (special dismal-map emacspeak-prefix))
      (local-unset-key "\M-[")
      (local-unset-key emacspeak-prefix)
-     (define-key dismal-map emacspeak-prefix 'emacspeak-prefix-command)
+     (define-key dismal-map emacspeak-prefix 'emacspeak-keymap)
      (define-key dismal-map (concat emacspeak-prefix "e")
                  'dis-last-column)
      (define-key dismal-map  "," 'emacspeak-dismal-display-cell-expression)
@@ -357,14 +355,14 @@ Checked by emacspeak specific dis-mode-hooks entry.")
      (define-key dismal-map "\M-m" 'emacspeak-dismal-row-summarize)
      (define-key dismal-map '[up] 'emacspeak-dismal-backward-row-and-summarize)
      (define-key dismal-map '[down] 'emacspeak-dismal-forward-row-and-summarize)
-     (define-key dismal-map '[left] 'emacspeak-dismal-backward-col-and-summarize)
-     (define-key dismal-map '[right] 'emacspeak-dismal-forward-col-and-summarize)))
+     (define-key
+      dismal-map '[left] 'emacspeak-dismal-backward-col-and-summarize)
+     (define-key
+      dismal-map '[right] 'emacspeak-dismal-forward-col-and-summarize)))
 
-;;}}}
-;;{{{  Advice some commands. 
+;;;   Advice some commands. 
 
-;;}}}
-;;{{{ customize for use with html helper mode
+;;;  customize for use with html helper mode
 (defadvice dis-html-dump-file (around emacspeak pre act comp)
   "Sets html-helper-build-new-buffer to nil first so we dont
 end up building a template page first."
@@ -377,12 +375,5 @@ end up building a template page first."
 
   (let ((html-helper-build-new-buffer nil)) ad-do-it))
 
-;;}}}
 (provide  'emacspeak-dismal)
-;;{{{  emacs local variables 
 
-;; local variables:
-;; folded-file: t
-;; end: 
-
-;;}}}
