@@ -1,22 +1,21 @@
-;;; emacspeak-emms.el --- Speech-enable EMMS Multimedia UI  -*- lexical-binding: t; -*-
+;;; emacspeak-emms.el --- Speech-enable EMMS -*- lexical-binding: t; -*-
 ;;
 ;; $Author: tv.raman.tv $
 ;; Description:  Emacspeak extension to speech-enable EMMS
 ;; Keywords: Emacspeak, Multimedia
-;;{{{  LCD Archive entry:
+;;;   LCD Archive entry:
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4150 $ |
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
+;;;   Copyright:
 
-;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (C) 1995 -- 2024, T. V. Raman
 ;; All Rights Reserved.
 ;; 
 ;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -33,12 +32,12 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  Introduction
+;;;   Introduction
 
 ;;; Commentary:
 ;; Speech-enables EMMS --- the Emacs equivalent of XMMS
@@ -50,16 +49,14 @@
 ;; 
 ;;; Code:
 
-;;}}}
-;;{{{ required modules
-(require 'cl-lib)
+;;  required modules
+(eval-when-compile (require 'cl-lib))
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (declare-function emms-playlist-current-selected-track "emacspeak-emms" t)
 (declare-function emms-player-pause "emacspeak-emms" t)
 
-;;}}}
-;;{{{ module emms:
+;;;  module emms:
 
 (defun emacspeak-emms-speak-current-track ()
   "Speak current track."
@@ -74,7 +71,7 @@
           `(defadvice ,f (after emacspeak pre act comp)
              "Speak track name."
              (when (ems-interactive-p)
-               (emacspeak-auditory-icon 'select-object)))))
+               (emacspeak-icon 'select-object)))))
 
 ;; these commands should not be made to talk since that would  interferes
 ;; with real work.
@@ -86,18 +83,19 @@
           `(defadvice ,f (after emacspeak pre act comp)
              "Provide auditory icon."
              (when (ems-interactive-p)
-               (emacspeak-auditory-icon 'select-object)))))
+               (emacspeak-icon 'select-object)))))
 
-(cl-loop for f in
-         '(emms-playlist-first emms-playlist-last
-                               emms-playlist-mode-first emms-playlist-mode-last)
-         do
-         (eval
-          `(defadvice ,f (after emacspeak pre act comp)
-             "speak."
-             (when (ems-interactive-p)
-               (emacspeak-auditory-icon 'large-movement)
-               (emacspeak-speak-line)))))
+(cl-loop
+ for f in
+ '(emms-playlist-first emms-playlist-last
+                       emms-playlist-mode-first emms-playlist-mode-last)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "speak."
+     (when (ems-interactive-p)
+       (emacspeak-icon 'large-movement)
+       (emacspeak-speak-line)))))
 (cl-loop for f in
          '(emms-browser emms-browser-next-filter
                         emms-browser-previous-filter)
@@ -107,33 +105,32 @@
              "speak."
              (when (ems-interactive-p)
                (emacspeak-speak-mode-line)
-               (emacspeak-auditory-icon 'open-object)))))
+               (emacspeak-icon 'open-object)))))
 
 (defadvice emms-browser-bury-buffer (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
     (emacspeak-speak-mode-line)
-    (emacspeak-auditory-icon 'close-object)))
+    (emacspeak-icon 'close-object)))
 
-;;}}}
-;;{{{ Module emms-streaming:
+;;;  Module emms-streaming:
 (cl-declaim (special emms-stream-mode-map))
 (defadvice emms-stream-mode (after emacspeak pre act comp)
   "Update keymaps."
   (define-key emms-stream-mode-map "\C-e"
-              'emacspeak-prefix-command))
+              'emacspeak-keymap))
 
 (defadvice emms-stream-delete-bookmark (after emacspeak pre act
                                               comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'delete-object)
+    (emacspeak-icon 'delete-object)
     (emacspeak-speak-line)))
 
 (defadvice emms-stream-save-bookmarks-file (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'save-object)
+    (emacspeak-icon 'save-object)
     (message "Saved stream bookmarks.")))
 
 (cl-loop for f in
@@ -159,19 +156,17 @@
 (defadvice emms-playlist-mode-bury-buffer (after emacspeak pre act comp)
   "Announce the buffer that becomes current."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
-;;}}}
-;;{{{ silence chatter from info
+;;;  silence chatter from info
 
 (defadvice emms-info-really-initialize-track (around emacspeak pre act comp)
   "Silence messages."
   (ems-with-messages-silenced
    ad-do-it))
 
-;;}}}
-;;{{{ pause/resume if needed
+;;;  pause/resume if needed
 
 (defun emacspeak-emms-pause-or-resume ()
   "Pause/resume if emms is running. For use  in
@@ -183,12 +178,6 @@ emacspeak-silence-hook."
 
 (add-hook 'emacspeak-silence-hook 'emacspeak-emms-pause-or-resume)
 
-;;}}}
 (provide 'emacspeak-emms)
-;;{{{ end of file
+;;;  end of file
 
-;; local variables:
-;; folded-file: t
-;; end:
-
-;;}}}
