@@ -3,19 +3,18 @@
 ;; $Author: tv.raman.tv $
 ;; Description:  Emacspeak extension to speech enable flyspell
 ;; Keywords: Emacspeak, Ispell, Spoken Output, fly spell checking
-;;{{{  LCD Archive entry:
+;;;   LCD Archive entry:
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ |
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman
 ;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;; All Rights Reserved.
 ;; 
@@ -33,12 +32,11 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  Introduction:
 
 ;;; Commentary:
 
@@ -59,15 +57,13 @@
 
 ;;; Code:
 
-;;}}}
-;;{{{ Requires
+;;;  Requires
 
-(require 'cl-lib)
+(eval-when-compile (require 'cl-lib))
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
-;;}}}
-;;{{{ define personalities
+;;;  define personalities
 
 (defgroup emacspeak-flyspell nil
   "Emacspeak support for on the
@@ -80,8 +76,7 @@ fly spell checking."
  '((flyspell-incorrect voice-bolden)
    (flyspell-duplicate voice-monotone-extra)))
 
-;;}}}
-;;{{{ advice
+;;;  advice
 
 (cl-declaim (special flyspell-delayed-commands))
 (when (fboundp 'emacspeak-self-insert-command)
@@ -95,9 +90,9 @@ fly spell checking."
      ad-do-it
      (dtk-speak (car (flyspell-get-word nil)))
      (when (sit-for 1)
-       (dtk-notify-speak (cl-second flyspell-auto-correct-ring)))
+       (dtk-notify (cl-second flyspell-auto-correct-ring)))
      (when (sit-for 1) (emacspeak-speak-message-again))
-     (emacspeak-auditory-icon 'select-object))) (t ad-do-it)) ad-return-value)
+     (emacspeak-icon 'select-object))) (t ad-do-it)) ad-return-value)
 
 (defadvice flyspell-unhighlight-at (before emacspeak pre act comp)
   "handle highlight/unhighlight."
@@ -112,11 +107,10 @@ fly spell checking."
 (add-hook
  'flyspell-incorrect-hook
  #'(lambda (_s _e p)
-     (unless (eq p 'doublon) (emacspeak-auditory-icon 'help))
+     (unless (eq p 'doublon) (emacspeak-icon 'help))
      nil))
 
-;;}}}
-;;{{{ use flyspell-correct if available:
+;;;  use flyspell-correct if available:
 (defcustom emacspeak-flyspell-correct
   (cond
    ((locate-library "flyspell-correct-ido") 'flyspell-correct-ido)
@@ -131,9 +125,9 @@ fly spell checking."
 (when
     (and (bound-and-true-p flyspell-mode-map)
          (locate-library "flyspell-correct"))
-  (define-key flyspell-mode-map (ems-kbd "C-x .") 'flyspell-correct-at-point)
-  (define-key flyspell-mode-map (ems-kbd "C-'") 'flyspell-correct-previous)
-  (define-key flyspell-mode-map (ems-kbd "C-;") 'flyspell-correct-wrapper)
+  (define-key flyspell-mode-map (kbd "C-x .") 'flyspell-correct-at-point)
+  (define-key flyspell-mode-map (kbd "C-'") 'flyspell-correct-previous)
+  (define-key flyspell-mode-map (kbd "C-;") 'flyspell-correct-wrapper)
   (require emacspeak-flyspell-correct))
 
 (cl-loop
@@ -146,14 +140,7 @@ fly spell checking."
      (when (ems-interactive-p)
        (dtk-speak (car (flyspell-get-word nil)))))))
 
-;;}}}
 (provide 'emacspeak-flyspell)
-;;{{{ emacs local variables
-
-;; local variables:
-;; folded-file: t
-;; end:
-
-;;}}}
+;;;  emacs local variables
 
 ;;; emacspeak-flyspell.el ends here
