@@ -1,21 +1,20 @@
-;;; emacspeak-make-mode.el --- Speech enable make-mode  -*- lexical-binding: t; -*-
+;;; emacspeak-make-mode.el --- Speech enable make  -*- lexical-binding: t; -*-
 ;;
 ;; $Author: tv.raman.tv $ 
 ;; Description:  Emacspeak extension to speech enable make-mode
 ;; Keywords: Emacspeak, Make
-;;{{{  LCD Archive entry: 
+;;;   LCD Archive entry: 
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ | 
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman 
 ;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;; All Rights Reserved. 
 ;; 
@@ -33,17 +32,15 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  required modules
+;;;   required modules
 
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-;;}}}
-;;{{{  Introduction:
 
 ;;; Commentary:
 
@@ -51,8 +48,7 @@
 
 ;;; Code:
 
-;;}}}
-;;{{{ advice
+;;;  advice
 
 (defadvice makefile-next-dependency (after emacspeak pre act
                                            comp)
@@ -60,28 +56,28 @@
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line)
-      (emacspeak-auditory-icon 'large-movement))))
+      (emacspeak-icon 'large-movement))))
 
 (defadvice makefile-browser-next-line (after emacspeak pre act
                                              comp)
   "Speak line we moved to"
   (when (ems-interactive-p)
     (emacspeak-speak-line)
-    (emacspeak-auditory-icon 'select-object)))
+    (emacspeak-icon 'select-object)))
 
 (defadvice makefile-browser-previous-line (after emacspeak pre act
                                                  comp)
   "Speak line we moved to"
   (when (ems-interactive-p)
     (emacspeak-speak-line)
-    (emacspeak-auditory-icon 'select-object)))
+    (emacspeak-icon 'select-object)))
 
 (defadvice makefile-previous-dependency (after emacspeak pre act comp)
   "Speak line we moved to"
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line)
-      (emacspeak-auditory-icon 'large-movement))))
+      (emacspeak-icon 'large-movement))))
 
 (defadvice makefile-complete (around emacspeak pre act comp)
   "Speak what we completed"
@@ -100,20 +96,20 @@
     (message "Backslashed region containing %s lines"
              (count-lines (region-beginning)
                           (region-end)))
-    (emacspeak-auditory-icon 'select-object)))
+    (emacspeak-icon 'select-object)))
 
 (defadvice makefile-browser-quit (after emacspeak pre act
                                         comp)
   "speak"
   (when (ems-interactive-p)
     (emacspeak-speak-mode-line)
-    (emacspeak-auditory-icon 'close-object)))
+    (emacspeak-icon 'close-object)))
 
 (defadvice makefile-switch-to-browser (after emacspeak pre
                                              act comp)
   "Provide status information"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'open-object)
+    (emacspeak-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice makefile-browser-toggle (around emacspeak pre act comp)
@@ -127,7 +123,7 @@
       ad-do-it
       (setq state
             (makefile-browser-get-state-for-line this-line))
-      (emacspeak-auditory-icon (if state 'on 'off))
+      (emacspeak-icon (if state 'on 'off))
       (emacspeak-speak-line)))
    (t ad-do-it))
   ad-return-value)
@@ -139,8 +135,7 @@
      "Inserted selections into client  %s"
      (buffer-name makefile-browser-client))))
 
-;;}}}
-;;{{{ personalities 
+;;;  personalities 
 
 (voice-setup-add-map
  '(
@@ -150,16 +145,9 @@
    (makefile-makepp-perl voice-smoothen)
    ))
 
-;;}}}
-;;{{{ setup mode hook:
+;;;  setup mode hook:
 
-;;}}}
 (provide 'emacspeak-make-mode)
 
-;;{{{ end of file 
+;;;  end of file 
 
-;; local variables:
-;; folded-file: t
-;; end: 
-
-;;}}}
