@@ -1,21 +1,20 @@
-;;; emacspeak-markdown.el --- Speech-enable MARKDOWN-mode.el  -*- lexical-binding: t; -*-
+;;; emacspeak-markdown.el --- Speech-enable MARKDOWN -*- lexical-binding: t; -*-
 ;; $Id: emacspeak-markdown.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
 ;; $Author: tv.raman.tv $
 ;; Description:  Speech-enable MARKDOWN An Emacs Interface to markdown
 ;; Keywords: Emacspeak,  Audio Desktop markdown
-;;{{{  LCD Archive entry:
+;;;   LCD Archive entry:
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ |
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman
 ;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;; All Rights Reserved.
 ;; 
@@ -33,57 +32,72 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  introduction
 
 ;;; Commentary:
 ;; MARKDOWN ==  Light-weight markup.
 ;; This module speech-enables markdown.el
 
-;;}}}
-;;{{{  Required modules
+;;   Required modules:
+;;; Code:
 
-(require 'cl-lib)
+(eval-when-compile (require 'cl-lib))
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-
-;;}}}
-;;{{{ Map faces to voices:
+;;;  Map faces to voices:
 (voice-setup-add-map
  '(
-   (markdown-italic-face  voice-animate)
+
+   
+   
+   
+   
+   
+   
+   (markdown-blockquote-face voice-lighten)
    (markdown-bold-face voice-bolden)
-   (markdown-header-rule-face voice-bolden-medium)
+   (markdown-code-face voice-monotone)
+   (markdown-comment-face voice-monotone-extra)
+   (markdown-footnote-marker-face voice-smoothen)
+   (markdown-footnote-text-face voice-smoothen)
    (markdown-header-delimiter-face voice-lighten)
    (markdown-header-face voice-bolden)
-   (markdown-header-face-1 voice-bolden-medium)
-   (markdown-header-face-2 voice-bolden-and-animate)
-   (markdown-header-face-3 voice-bolden-extra)
+   (markdown-header-face-1 voice-brighten)
+   (markdown-header-face-2 voice-animate)
+   (markdown-header-face-3 voice-lighten)
    (markdown-header-face-4 voice-smoothen)
-   (markdown-header-face-5 voice-lighten-extra)
+   (markdown-header-face-5 voice-monotone)
    (markdown-header-face-6 voice-monotone-extra)
+   (markdown-header-rule-face voice-bolden-medium)
+   (markdown-highlight-face voice-animate)
+   (markdown-highlighting-face voice-animate)
+   (markdown-html-attr-name-face voice-lighten)
+   (markdown-html-attr-value-face voice-brighten)
+   (markdown-html-entity-face voice-smoothen)
+   (markdown-html-tag-name-face voice-bolden)
    (markdown-inline-code-face voice-monotone-extra)
-   (markdown-list-face voice-animate)
-   (markdown-blockquote-face voice-lighten)
-   (markdown-pre-face voice-monotone-extra)
+   (markdown-italic-face  voice-animate)
    (markdown-language-keyword-face voice-smoothen)
-   (markdown-link-face voice-bolden)
-   (markdown-missing-link-face voice-animate)
-   (markdown-reference-face voice-lighten)
-   (markdown-url-face voice-bolden-and-animate)
-   (markdown-link-title-face voice-lighten)
    (markdown-line-break-face voice-monotone-extra)
-   (markdown-comment-face voice-monotone-extra)
+   (markdown-link-face voice-bolden)
+   (markdown-link-title-face voice-lighten)
+   (markdown-list-face voice-animate)
    (markdown-math-face voice-animate)
    (markdown-metadata-key-face voice-smoothen)
    (markdown-metadata-value-face voice-smoothen-medium)
+   (markdown-missing-link-face voice-animate)
+   (markdown-plain-url-face voice-lighten)
+   (markdown-pre-face voice-monotone-extra)
+   (markdown-reference-face voice-lighten)
+   (markdown-table-face voice-monotone)
+   (markdown-url-face voice-bolden-and-animate)
    ))
-;;}}}
-;;{{{ Advice Interactive Commands:
+
+;;;  Advice Interactive Commands:
 (cl-loop
  for f in
  '(markdown-outdent-or-delete markdown-exdent-or-delete)
@@ -102,6 +116,7 @@
 (cl-loop
  for f in
  '(
+   markdown-back-to-heading
    markdown-backward-block markdown-backward-page
    markdown-beginning-of-list markdown-beginning-of-text-block
    markdown-edit-code-block markdown-end-of-list
@@ -151,7 +166,7 @@
   `(defadvice ,f (after emacspeak pre act comp)
      "speak."
      (when (ems-interactive-p)
-       (emacspeak-auditory-icon 'large-movement)
+       (emacspeak-icon 'large-movement)
        (emacspeak-speak-line)))))
 
 (cl-loop
@@ -165,7 +180,7 @@
   `(defadvice ,f (after emacspeak pre act comp)
      "speak."
      (when (ems-interactive-p)
-       (emacspeak-auditory-icon 'task-done)
+       (emacspeak-icon 'task-done)
        (emacspeak-speak-line)))))
 
 (cl-loop
@@ -178,15 +193,20 @@
   `(defadvice ,f (after emacspeak pre act comp)
      "speak."
      (when (ems-interactive-p)
-       (emacspeak-auditory-icon 'complete)
+       (emacspeak-icon 'complete)
        (emacspeak-speak-line)))))
+;;; Eepeat-mode:
+(cl-declaim (special markdown-mode-map))
+(when (and (bound-and-true-p markdown-mode-map) (keymapp  markdown-mode-map))
+  (map-keymap
+   (lambda (_key cmd)
+     (when
+         (and
+          (symbolp cmd)
+          (not (eq cmd 'digit-argument)))
+       (put cmd 'repeat-map 'markdown-mode-map)))
+   markdown-mode-map))
 
-;;}}}
 (provide 'emacspeak-markdown)
-;;{{{ end of file
+;;;  end of file
 
-;; local variables:
-;; folded-file: t
-;; end:
-
-;;}}}
