@@ -1,21 +1,20 @@
-;;; emacspeak-message.el --- Speech enable Message -- Used to compose news postings and replies  -*- lexical-binding: t; -*-
+;;; emacspeak-message.el --- Speech enable Message   -*- lexical-binding: t; -*-
 ;;
 ;; $Author: tv.raman.tv $ 
 ;; Description: Emacspeak extensions for posting
 ;; Keywords:emacspeak, audio interface to emacs posting messages
-;;{{{  LCD Archive entry: 
+;;;   LCD Archive entry: 
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ | 
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman 
 ;; Copyright (c) 1995 by T. V. Raman  
 ;; All Rights Reserved. 
 ;; 
@@ -33,37 +32,27 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 
-;;{{{  Introduction
+;;;   Introduction
 ;;; Commentary:
 ;; advice for posting message commands
 ;;; Code:
-;;}}}
-;;{{{ requires
+
+;;;  requires
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
-;;}}}
-;;{{{ customize
+;;;  customize
 (defgroup emacspeak-message nil
   "Emacspeak customizations for message mode"
   :group 'emacspeak
   :group 'message
   :prefix "emacspeak-message-")
 
-(defcustom emacspeak-message-punctuation-mode  'all
-  "Pronunciation mode to use for message buffers."
-  :type '(choice
-          (const  :tag "Ignore" nil)
-          (const  :tag "some" some)
-          (const  :tag "all" all))
-  :group 'emacspeak-message)
-
-;;}}}
-;;{{{ voice mapping
+;;;  voice mapping
 
 (voice-setup-add-map
  '(
@@ -78,8 +67,7 @@
    (message-mml voice-brighten)
    (message-separator voice-bolden-extra)))
 
-;;}}}
-;;{{{  advice interactive commands
+;;;   advice interactive commands
 (cl-loop
  for f in
  '(message-send message-send-and-exit)
@@ -89,96 +77,96 @@
      "Provide auditory context"
      (when  (ems-interactive-p)
        (emacspeak-speak-mode-line)
-       (emacspeak-auditory-icon 'close-object)))))
+       (emacspeak-icon 'close-object)))))
 
 (defadvice message-goto-to (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-summary (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-subject (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-cc (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-bcc (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-fcc (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-keywords (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-newsgroups (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-followup-to (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-reply-to (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-body (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (message "Beginning of message body")))
 
 (defadvice message-goto-signature (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-distribution (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-insert-citation-line (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-insert-to (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-insert-signature (after emacspeak pre act comp)
@@ -189,53 +177,41 @@
 (defadvice message-insert-newsgroups (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-insert-courtesy-copy (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-beginning-of-line (before emacspeak pre act comp)
   "Stop speech first."
-  (when (ems-interactive-p) (dtk-stop)
-        (emacspeak-auditory-icon 'select-object)
+  (when (ems-interactive-p) (dtk-stop 'all)
+        (emacspeak-icon 'select-object)
         (dtk-speak "beginning of line")))
 
 (defadvice message-goto-from (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-goto-mail-followup-to (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice message-newline-and-reformat (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'fill-object)
+    (emacspeak-icon 'fill-object)
     (message "newline and reformat")))
 
 (add-hook 'message-mode-hook
-          (lambda ()
-            (dtk-set-punctuations emacspeak-message-punctuation-mode)
-            (emacspeak-pronounce-refresh-pronunciations)
-            (emacspeak-auditory-icon 'open-object)
-            (message "Starting message %s ... done"
-                     (buffer-name))))
+          #'emacspeak-pronounce-refresh-pronunciations)
 
-;;}}}
 (provide  'emacspeak-message)
-;;{{{  emacs local variables 
 
-;; local variables:
-;; folded-file: t
-;; end: 
-
-;;}}}
