@@ -1,22 +1,21 @@
-;;; emacspeak-newsticker.el --- Speech-enable newsticker  -*- lexical-binding: t; -*-
+;;; emacspeak-newsticker.el --- newsticker  -*- lexical-binding: t; -*-
 ;;
 ;; $Author: tv.raman.tv $
 ;; Description:  Emacspeak front-end for NEWSTICKER 
 ;; Keywords: Emacspeak, newsticker 
-;;{{{  LCD Archive entry:
+;;;   LCD Archive entry:
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4074 $ |
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
+;;;   Copyright:
 
-;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (C) 1995 -- 2024, T. V. Raman
 ;; All Rights Reserved.
 ;; 
 ;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -33,34 +32,32 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;; Commentary:
-;;{{{  Introduction:
 
 ;; Newsticker provides a continuously updating newsticker using
 ;; RSS
 ;; Provides functionality similar to amphetadesk --but in pure elisp
 
-;;}}}
-;;{{{ required modules
+;;  required modules
 
 ;;; Code:
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-;;}}}
-;;{{{ define personalities 
+
+;;;  define personalities 
 (voice-setup-add-map
  '(
    (newsticker-new-item-face voice-brighten)
    (newsticker-old-item-face voice-monotone-extra)
    (newsticker-feed-face voice-animate)
    ))
-;;}}}
-;;{{{ advice functions
+
+;;;  advice functions
 
 (defadvice newsticker--cache-remove (around emacspeak pre act
                                             comp)
@@ -81,8 +78,7 @@
     ad-do-it
     ad-return-value))
 
-;;}}}
-;;{{{ advice interactive commands
+;;;  advice interactive commands
 
 (defun emacspeak-newsticker-summarize-item ()
   "Summarize current item."
@@ -99,11 +95,10 @@
           `(defadvice ,f (after emacspeak pre act comp)
              "Speak."
              (when (ems-interactive-p)
-               (emacspeak-auditory-icon 'large-movement)
+               (emacspeak-icon 'large-movement)
                (emacspeak-newsticker-summarize-item)))))
 
-;;}}}
-;;{{{  silence auto activity
+;;;   silence auto activity
 
 (cl-loop for f in
          '(newsticker-get-news-with-delay
@@ -115,12 +110,7 @@
              "Silence messages."
              (let ((emacspeak-speak-messages nil))
                ad-do-it))))
-;;}}}
+
 (provide 'emacspeak-newsticker)
-;;{{{ end of file
+;;;  end of file
 
-;; local variables:
-;; folded-file: t
-;; end:
-
-;;}}}
