@@ -1,21 +1,20 @@
-;;; emacspeak-rmail.el --- Speech enable RMail -- Emacs' default mail agent  -*- lexical-binding: t; -*-
+;;; emacspeak-rmail.el --- Speech enable RMail -*- lexical-binding: t; -*-
 ;;
 ;; $Author: tv.raman.tv $ 
 ;; Description: Emacspeak extension for rmail
 ;; Keywords:emacspeak, audio interface to emacs mail
-;;{{{  LCD Archive entry: 
+;;;   LCD Archive entry: 
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ | 
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman 
 ;; Copyright (c) 1995 by T. V. Raman  
 ;; All Rights Reserved. 
 ;; 
@@ -33,21 +32,20 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 
-;;{{{  Introduction
+;;;   Introduction
 ;;; Commentary:
 ;; emacspeak extensions to rmail
 ;;; Code:
-;;}}}
-;;{{{ requires
+
+;;;  requires
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
-;;}}}
-;;{{{  customizations:
+;;;   customizations:
 (declare-function rmail-display-labels "rmail" nil)
 (declare-function rmail-msgend "rmail" (n))
 (declare-function rmail-msgbeg "rmail" (n))
@@ -60,8 +58,7 @@
               "^Mime-\\|"
               rmail-ignored-headers))
 
-;;}}}
-;;{{{  helper functions:
+;;;   helper functions:
 
 (defun emacspeak-rmail-summarize-message (message)
   "Summarize message in rmail identified by message number message"
@@ -79,83 +76,80 @@
              (if lines (format "%s lines" lines) "")
              labels))))
 
-;;}}}
-;;{{{  Advice some commands.
-;;{{{  buffer selection
+;;;   Advice some commands.
+;;;   buffer selection
 
 (defadvice rmail-quit(after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'close-object)
+    (emacspeak-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice rmail-bury(after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-speak-mode-line)))
 (defadvice rmail (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-rmail-summarize-current-message)))
 
 (defadvice rmail-expunge-and-save (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'save-object)))
+    (emacspeak-icon 'save-object)))
 
-;;}}}
-;;{{{  message navigation
+;;;   message navigation
 
 (defadvice rmail-beginning-of-message (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speak-line)))
 
-;;}}}
-;;{{{  folder navigation
+;;;   folder navigation
 
 (defadvice rmail-first-message (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 
 (defadvice rmail-first-unseen-message (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 
 (defadvice rmail-last-message (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 
 (defadvice rmail-next-undeleted-message (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 
 (defadvice rmail-next-message (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 
 (defadvice rmail-previous-undeleted-message (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 (defadvice rmail-previous-message (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 (defadvice rmail-next-labeled-message (around emacspeak pre act comp)
   "speak"
@@ -166,9 +160,9 @@
       ad-do-it
       (cond
        ((not (= original rmail-current-message))
-        (emacspeak-auditory-icon 'select-object)
+        (emacspeak-icon 'select-object)
         (emacspeak-rmail-summarize-message rmail-current-message))
-       (t (emacspeak-auditory-icon 'search-miss)))))
+       (t (emacspeak-icon 'search-miss)))))
    (t ad-do-it))
   ad-return-value)
 
@@ -180,47 +174,45 @@
       ad-do-it
       (cond
        ((not (= original rmail-current-message))
-        (emacspeak-auditory-icon 'select-object)
+        (emacspeak-icon 'select-object)
         (emacspeak-rmail-summarize-message rmail-current-message))
-       (t (emacspeak-auditory-icon 'search-miss)))))
+       (t (emacspeak-icon 'search-miss)))))
    (t ad-do-it))
   ad-return-value)
 
 (defadvice rmail-show-message (after emacspeak pre act comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))  
 
-;;}}}
-;;{{{ delete and undelete messages
+;;;  delete and undelete messages
 
 (defadvice rmail-undelete-previous-message (after emacspeak pre act
                                                   comp)
   "speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-rmail-summarize-current-message)))
 (defadvice rmail-delete-message (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'delete-object)
+    (emacspeak-icon 'delete-object)
     (message "Message discarded.")))
 
 (defadvice rmail-delete-forward (after emacspeak pre act comp)
   "provide auditory feedback"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'delete-object)
+    (emacspeak-icon 'delete-object)
     (emacspeak-rmail-summarize-current-message)))
 
 (defadvice rmail-delete-backward (after emacspeak pre act comp)
   "provide auditory feedback"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'delete-object)
-    (emacspeak-rmail-summarize-current-message))) ;;}}}
+    (emacspeak-icon 'delete-object)
+    (emacspeak-rmail-summarize-current-message)))  
 
-;;}}}
-;;{{{  Additional interactive commands
+;;;   Additional interactive commands
 
 (defun emacspeak-rmail-summarize-current-message ()
   "Summarize current message"
@@ -234,20 +226,12 @@
    (format "Labels are %s"
            (rmail-display-labels))))
 
-;;}}}
-;;{{{  key bindings
+;;;   key bindings
 (when (and (boundp 'rmail-mode-map) (keymapp rmail-mode-map))  
   (cl-declaim (special rmail-mode-map))
   (define-key rmail-mode-map "\C-m" 'emacspeak-rmail-summarize-current-message)
   (define-key rmail-mode-map "L"
               'emacspeak-rmail-speak-current-message-labels))
 
-;;}}}
 (provide  'emacspeak-rmail)
-;;{{{  emacs local variables 
 
-;; local variables:
-;; folded-file: t
-;; end: 
-
-;;}}}
