@@ -1,22 +1,21 @@
-;;; emacspeak-speedbar.el --- Speech enable speedbar -- Tool for context-sensitive navigation  -*- lexical-binding: t; -*-
+;;; emacspeak-speedbar.el --- speedbar - -*- lexical-binding: t; -*-
 ;;
 ;; $Author: tv.raman.tv $ 
 ;; Description: Auditory interface to speedbar
 ;; Keywords: Emacspeak, Speedbar
-;;{{{  LCD Archive entry: 
+;;;   LCD Archive entry: 
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ | 
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
+;;;   Copyright:
 
-;; Copyright (c) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1995 -- 2024, T. V. Raman
 ;; All Rights Reserved. 
 ;; 
 ;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -33,12 +32,12 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  Introduction
+;;;   Introduction
 
 ;;; Commentary:
 
@@ -53,14 +52,13 @@
 
 ;;; Code:
 
-;;}}}
-;;{{{  Required modules
+;;   Required modules:
 
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'speedbar "speedbar" 'no-error)
-;;}}}
-;;{{{ Helper:
+
+;;;  Helper:
 
 (defun emacspeak-speedbar-speak-line()
   "Speak a line in the speedbar display"
@@ -81,13 +79,12 @@
       (dtk-speak 
        (concat indent (ems--this-line))))))
 
-;;}}}
-;;{{{ Advice interactive commands:
+;;;  Advice interactive commands:
 
 (defadvice speedbar-close-frame (after emacspeak pre act comp)
   "Cue buffer that becomes active"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'close-object)
+    (emacspeak-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice speedbar-next (around emacspeak pre act comp)
@@ -97,7 +94,7 @@
     (let ((emacspeak-speak-messages nil))
       ad-do-it
       (emacspeak-speedbar-speak-line)
-      (emacspeak-auditory-icon 'select-object)))
+      (emacspeak-icon 'select-object)))
    (t ad-do-it))
   ad-return-value)
 (defadvice speedbar-prev (around emacspeak pre act comp)
@@ -107,13 +104,13 @@
     (let ((emacspeak-speak-messages nil))
       ad-do-it
       (emacspeak-speedbar-speak-line)
-      (emacspeak-auditory-icon 'select-object)))
+      (emacspeak-icon 'select-object)))
    (t ad-do-it))
   ad-return-value)
 (defadvice speedbar-edit-line (after emacspeak pre act comp)
   "Speak line you jumped to"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)))
+    (emacspeak-icon 'large-movement)))
 
 (defadvice speedbar-tag-find (after emacspeak pre act comp)
   "Speak the line you jumped to"
@@ -121,7 +118,7 @@
 
 (defadvice speedbar-find-file (after emacspeak pre act comp)
   "Speak modeline of buffer we switched to"
-  (emacspeak-auditory-icon 'select-object)
+  (emacspeak-icon 'select-object)
   (emacspeak-speak-mode-line))
 
 (defadvice speedbar-expand-line (after emacspeak pre act
@@ -129,13 +126,13 @@
   "Speak the line we just expanded"
   (when (ems-interactive-p) 
     (emacspeak-speedbar-speak-line)
-    (emacspeak-auditory-icon 'open-object)))
+    (emacspeak-icon 'open-object)))
 
 (defadvice speedbar-contract-line (after emacspeak pre act comp)
   "Speak the line we just contracted"
   (when (ems-interactive-p) 
     (emacspeak-speedbar-speak-line)
-    (emacspeak-auditory-icon 'close-object)))
+    (emacspeak-icon 'close-object)))
 
 (defadvice speedbar-up-directory (around emacspeak pre act comp)
   " Auditory icon and speech feedback indicate result of the
@@ -143,7 +140,7 @@ action"
   (cond
    ((ems-interactive-p)
     ad-do-it
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speedbar-speak-line))
    (t ad-do-it))
   ad-return-value)
@@ -152,18 +149,17 @@ action"
                                            comp)
   "Speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speedbar-speak-line)))
 
 (defadvice speedbar-restricted-prev (after emacspeak pre act
                                            comp)
   "Speak"
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (emacspeak-speedbar-speak-line)))
 
-;;}}}
-;;{{{ additional navigation
+;;;  additional navigation
 
 (defvar emacspeak-speedbar-disable-updates t
   "Non nil means speedbar does not automatically update.
@@ -181,7 +177,7 @@ An automatically updating speedbar consumes resources.")
   (when emacspeak-speedbar-disable-updates 
     (speedbar-stealthy-updates)
     (speedbar-disable-update))
-  (emacspeak-auditory-icon 'select-object)
+  (emacspeak-icon 'select-object)
   (dtk-speak
    (concat "Speedbar: "
            (let ((start nil))
@@ -208,16 +204,14 @@ An automatically updating speedbar consumes resources.")
                (forward-char 1)
                (setq action-char (following-char))
                (emacspeak-speedbar-speak-line)
-               (emacspeak-auditory-icon
+               (emacspeak-icon
                 (cl-case action-char
                   (?+ 'open-object)
                   (?- 'close-object)
                   (t 'large-movement))))
        (t (message "No target on this line"))))))
 
-;;}}}
-;;{{{  hooks
-(cl-declaim (special speedbar-mode-map))
+;;;   hooks
 (cl-eval-when (load)
   )
 (defun emacspeak-speedbar-enter-hook ()
@@ -237,8 +231,7 @@ An automatically updating speedbar consumes resources.")
 (add-hook 'speedbar-mode-hook
           'emacspeak-speedbar-enter-hook)
 
-;;}}}
-;;{{{  voice locking 
+;;;   voice locking 
 ;; Map speedbar faces to voices
 ;;
 (defvar emacspeak-speedbar-button-personality  voice-bolden
@@ -289,18 +282,9 @@ An automatically updating speedbar consumes resources.")
       (save-match-data
         (beginning-of-line)))))
 
-;;}}}
-;;{{{ keys 
+;;;  keys 
 (cl-declaim (special emacspeak-keymap))
 
-                                        ;(define-key emacspeak-keymap '[insert] 'emacspeak-speedbar-goto-speedbar)
-
-;;}}}
 (provide 'emacspeak-speedbar)
-;;{{{ end of file 
+;;;  end of file 
 
-;; local variables:
-;; folded-file: t
-;; end: 
-
-;;}}}
