@@ -3,19 +3,18 @@
 ;; $Author: tv.raman.tv $
 ;; Description:  Emacspeak extension to speech enable sql-mode
 ;; Keywords: Emacspeak, database interaction
-;;{{{  LCD Archive entry:
+;;;   LCD Archive entry:
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ |
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman 
 ;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;; All Rights Reserved.
 ;; 
@@ -33,17 +32,15 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{ required modules
-(require 'cl-lib)
+;;  required modules
+(eval-when-compile (require 'cl-lib))
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-;;}}}
-;;{{{  Introduction:
 
 ;;; Commentary:
 
@@ -55,51 +52,50 @@
 ;; interactively evaluate SQL expressions.
 ;;; Code:
 
-;;}}}
-;;{{{ advice
+;;;  advice
 
 (defadvice sqlplus-execute-command (after emacspeak pre act comp)
   "speak and place point at the start of the output."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'scroll)
+    (emacspeak-icon 'scroll)
     (sqlplus-back-command 2)
     (forward-line 1)
     (emacspeak-speak-line)))
 
-(defadvice sqlplus-back-command (after emacspeak pre act
-                                       comp)"Move prompt appropriately,  and speak the line."
-                                       (when (ems-interactive-p)
-                                         (emacspeak-auditory-icon 'large-movement)
-                                         (forward-line 1)
-                                         (emacspeak-speak-line)))
+(defadvice sqlplus-back-command (after emacspeak pre act comp)
+  "Move prompt appropriately,  and speak the line."
+  (when (ems-interactive-p)
+    (emacspeak-icon 'large-movement)
+    (forward-line 1)
+    (emacspeak-speak-line)))
 
 (defadvice sqlplus-forward-command (after emacspeak pre act
                                           comp)
   "Move prompt appropriately,  and speak the line."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-icon 'large-movement)
     (forward-line 1)
     (emacspeak-speak-line)))
 
 (defadvice sqlplus-next-command (after emacspeak pre act comp)
   "Speak the line."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice sqlplus-previous-command (after emacspeak pre act comp)
   "Speak the line."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice sql-send-region (around emacspeak pre act comp)
   "speak."
   (cond
    ((ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     ad-do-it
-    (emacspeak-auditory-icon 'mark-object))
+    (emacspeak-icon 'mark-object))
    (t ad-do-it))
   ad-return-value)
 
@@ -107,19 +103,13 @@
   "speak."
   (cond
    ((ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-icon 'select-object)
     ad-do-it
-    (emacspeak-auditory-icon 'mark-object))
+    (emacspeak-icon 'mark-object))
    (t ad-do-it))
   ad-return-value)
 
-;;}}}
 (provide 'emacspeak-sql)
 
-;;{{{ end of file
+;;;  end of file
 
-;; local variables:
-;; folded-file: t
-;; end:
-
-;;}}}
