@@ -1,21 +1,20 @@
-;;; emacspeak-table.el --- Implements data model for table browsing  -*- lexical-binding: t; -*-
+;;; emacspeak-table.el --- Table data model -*- lexical-binding: t; -*-
 ;;
 ;; $Author: tv.raman.tv $ 
 ;; Description: Emacspeak table handling module
 ;; Keywords:emacspeak, audio interface to emacs tables are structured
-;;{{{  LCD Archive entry: 
+;;;   LCD Archive entry: 
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ | 
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman 
 ;; Copyright (c) 1995 by T. V. Raman  
 ;; All Rights Reserved. 
 ;; 
@@ -33,25 +32,23 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 
-;;{{{  Introduction
+;;;   Introduction
 
 ;;; Commentary:
 ;; Implements a module that provides a high level interface to
 ;; tabulated information.
 ;;; Code:
 
-;;}}}
-;;{{{ requires
+;;;  requires
 
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
-;;}}}
-;;{{{  Define table data structure:
+;;;   Define table data structure:
 
 ;; Tables will be represented internally as vectors.
 ;; User of a table can:
@@ -101,8 +98,7 @@ vectors")
     (setf (emacspeak-table-current-column table) 0)
     table))
 
-;;}}}
-;;{{{ Accessors
+;;;  Accessors
 
 (defun emacspeak-table-this-element (table row column)
   (let ((elements (emacspeak-table-elements  table)))
@@ -139,8 +135,7 @@ vectors")
 (defun emacspeak-table-row-header-element (table row)
   (aref (emacspeak-table-row-header table) row))
 
-;;}}}
-;;{{{  enumerators
+;;;   enumerators
 
 (defun emacspeak-table-enumerate-rows (table callback &rest callback-args)
   "Enumerates the rows of a table.
@@ -161,8 +156,7 @@ Calls callback once per column."
             (emacspeak-table-this-column table column)
             callback-args))))
 
-;;}}}
-;;{{{ finders 
+;;;  finders 
 
 (defun emacspeak-table-find-match-in-row (table index pattern
                                                 &optional predicate)
@@ -201,8 +195,7 @@ Calls callback once per column."
              until found
              finally return (and found row))))
 
-;;}}}
-;;{{{  Moving point:
+;;;   Moving point:
 
 (defun emacspeak-table-goto-cell (table row column)
   "Move to a cell of the table"
@@ -228,7 +221,7 @@ Calls callback once per column."
       (setf (emacspeak-table-current-row table) new))
      (t (message "Cannot move up by %s rows from row %s" count
                  current)
-        (emacspeak-auditory-icon 'warn-user)))))
+        (emacspeak-icon 'warn-user)))))
 
 (defun emacspeak-table-move-down (table &optional count)
   "Move down in the table if possible."
@@ -241,7 +234,7 @@ Calls callback once per column."
       (setf (emacspeak-table-current-row table) new))
      (t (message "Cannot move down by %s rows from row %s"
                  count current)
-        (emacspeak-auditory-icon 'warn-user)))))
+        (emacspeak-icon 'warn-user)))))
 
 (defun emacspeak-table-move-left (table &optional count)
   "Move left in the table if possible."
@@ -253,7 +246,7 @@ Calls callback once per column."
       (setf (emacspeak-table-current-column table) new))
      (t (message "Cannot move left by %s columns from column %s"
                  count current)
-        (emacspeak-auditory-icon 'warn-user)))))
+        (emacspeak-icon 'warn-user)))))
 
 (defun emacspeak-table-move-right (table &optional count)
   "Move right in the table if possible."
@@ -266,15 +259,7 @@ Calls callback once per column."
       (setf (emacspeak-table-current-column table) new))
      (t (message "Cannot move right by %s columns from column %s"
                  count current)
-        (emacspeak-auditory-icon 'warn-user)))))
-
-;;}}}
+        (emacspeak-icon 'warn-user)))))
 
 (provide  'emacspeak-table)
-;;{{{  emacs local variables 
 
-;; local variables:
-;; folded-file: t
-;; end: 
-
-;;}}}
