@@ -3,20 +3,19 @@
 ;; $Author: tv.raman.tv $
 ;; Description:  Emacspeak extension to make Web searching convenient
 ;; Keywords: Emacspeak, WWW interaction
-;;{{{  LCD Archive entry:
+;;;   LCD Archive entry:
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4625 $ |
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
+;;;   Copyright:
 
-;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (C) 1995 -- 2024, T. V. Raman
 ;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;; All Rights Reserved.
 ;; 
@@ -34,11 +33,10 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;{{{  Introduction:
 
 ;;; Commentary:
 
@@ -46,9 +44,9 @@
 
 ;;; Code:
 
-;;}}}
-;;{{{ required modules
-(require 'cl-lib)
+
+;;  required modules
+(eval-when-compile (require 'cl-lib))
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'emacspeak-google)
@@ -57,16 +55,12 @@
 (declare-function calendar-cursor-to-date "calendar" (&optional error event))
 (declare-function emacspeak-eww-autospeak "emacspeak-eww" nil)
 
-;;}}}
-;;{{{ Forward Declarations:
-
-(defvar emacspeak-wizards-personal-portfolio)
+;;;  Forward Declarations:
 
 (declare-function gweb-google-autocomplete "gweb" (&optional prompt))
 (declare-function calendar-astro-date-string "cal-julian" (&optional date))
 
-;;}}}
-;;{{{ searcher table
+;;;  searcher table
 
 (defvar emacspeak-websearch-table (make-hash-table)
   "Table to map  search engine names to appropriate searcher functions.")
@@ -79,8 +73,7 @@
   (cl-declare (special emacspeak-websearch-table))
   (gethash engine emacspeak-websearch-table))
 
-;;}}}
-;;{{{ Key table
+;;;  Key table
 
 (defvar emacspeak-websearch-keytable (make-hash-table)
   "Table holding mapping from keys to appropriate search engine names.")
@@ -93,8 +86,7 @@
   (cl-declare (special emacspeak-websearch-keytable))
   (gethash key emacspeak-websearch-keytable))
 
-;;}}}
-;;{{{ top-level dispatch
+;;;  top-level dispatch
 
 (defun emacspeak-websearch-help ()
   "Displays key mapping used by Emacspeak Websearch."
@@ -117,7 +109,7 @@
       (goto-char (point-min)))
     (pop-to-buffer (help-buffer))
     (emacspeak-speak-mode-line)
-    (emacspeak-auditory-icon 'help)))
+    (emacspeak-icon 'help)))
 
 (emacspeak-websearch-set-searcher  'help
                                    'emacspeak-websearch-help)
@@ -142,8 +134,7 @@
         (call-interactively searcher)
       (error "I do not know how to search using %s" engine))))
 
-;;}}}
-;;{{{ helpers to read the query
+;;;  helpers to read the query
 
 (defvar emacspeak-websearch-history nil
   "Holds history of search queries.")
@@ -160,8 +151,7 @@
     (cl-pushnew answer  emacspeak-websearch-history :test #'string=)
     answer))
 
-;;}}}
-;;{{{post-processor
+;;; post-processor
 (defun emacspeak-websearch-post-process (locator speaker &rest args)
   "Set up post processing steps on a result page.
 LOCATOR is a string to search for in the results page.
@@ -182,9 +172,7 @@ ARGS specifies additional arguments to SPEAKER if any."
              (error nil)))))
    'at-end))
 
-;;}}}
-
-;;{{{ Computer Science Bibliography
+;;;  Computer Science Bibliography
 
 (emacspeak-websearch-set-searcher 'biblio
                                   'emacspeak-websearch-biblio-search)
@@ -192,7 +180,9 @@ ARGS specifies additional arguments to SPEAKER if any."
 (emacspeak-websearch-set-key 2 'biblio)
 
 (defvar emacspeak-websearch-biblio-uri
-  "http://liinwww.ira.uka.de/searchbib/index?partial=on&case=on&results=citation&maxnum=200&query="
+  (concat
+   "http://liinwww.ira.uka.de/searchbib/index"
+   "?partial=on&case=on&results=citation&maxnum=200&query=")
   "URI to search the Computer Science Bibliographies.")
 
 (defun emacspeak-websearch-biblio-search (query)
@@ -208,30 +198,7 @@ ARGS specifies additional arguments to SPEAKER if any."
    query
    'emacspeak-speak-line))
 
-;;}}}
-;;{{{ CiteSeer Citation index
-
-(defvar emacspeak-websearch-citeseer-uri
-  "https://citeseerx.ist.psu.edu/search?t=doc&sort=rlv&s2=Semantic+Scholar&submit=Search&q=%s"
-  "URI for searching CiteSeer index. ")
-
-(emacspeak-websearch-set-searcher
- 'citeseer
- 'emacspeak-websearch-citeseer-search)
-
-(emacspeak-websearch-set-key 3 'citeseer)
-
-(defun emacspeak-websearch-citeseer-search(term)
-  "Perform a CiteSeer search. "
-  (interactive
-   (list (emacspeak-websearch-read-query "Enter CiteSeer query term:")))
-  (cl-declare (special emacspeak-websearch-citeseer-uri))
-  (browse-url
-   (format  emacspeak-websearch-citeseer-uri (url-hexify-string term)))
-  (emacspeak-websearch-post-process term  #'emacspeak-speak-line))
-
-;;}}}
-;;{{{ FolDoc
+;;;  FolDoc
 
 (emacspeak-websearch-set-searcher 'foldoc
                                   'emacspeak-websearch-foldoc-search)
@@ -254,8 +221,7 @@ ARGS specifies additional arguments to SPEAKER if any."
    query
    'emacspeak-speak-line))
 
-;;}}}
-;;{{{ Gutenberg
+;;;  Gutenberg
 
 (emacspeak-websearch-set-searcher 'gutenberg
                                   'emacspeak-websearch-gutenberg)
@@ -282,8 +248,7 @@ ARGS specifies additional arguments to SPEAKER if any."
    query
    'emacspeak-speak-line))
 
-;;}}}
-;;{{{ google
+;;;  google
 (emacspeak-websearch-set-searcher 'google-lucky
                                   'emacspeak-websearch-google-feeling-lucky)
 
@@ -330,6 +295,7 @@ ARGS specifies additional arguments to SPEAKER if any."
 
 (defvar emacspeak-websearch-google-number-of-results 25
   "Number of Google search results.")
+(declare-function emacspeak-eww-next-h "emacspeak-eww" (&optional speak))
 (declare-function emacspeak-eww-next-h1 "emacspeak-eww" (&optional speak))
 
 ;;;###autoload
@@ -338,10 +304,12 @@ ARGS specifies additional arguments to SPEAKER if any."
 `flag' prompts for additional search options. Second interactive
 prefix arg is equivalent to hitting the I'm Feeling Lucky button on Google. "
   (interactive (list (gweb-google-autocomplete) current-prefix-arg))
-  (cl-declare (special emacspeak-google-query
-                       emacspeak-google-toolbelt
-                       ems--websearch-google-filter
-                       emacspeak-websearch-google-options emacspeak-websearch-google-number-of-results))
+  (cl-declare (special
+               emacspeak-google-query
+               emacspeak-google-toolbelt
+               ems--websearch-google-filter
+               emacspeak-websearch-google-options
+               emacspeak-websearch-google-number-of-results))
   (setq emacspeak-google-toolbelt nil)
   (let ((toolbelt (emacspeak-google-toolbelt))
         (search-url nil)
@@ -370,7 +338,11 @@ prefix arg is equivalent to hitting the I'm Feeling Lucky button on Google. "
        'emacspeak-eww-post-process-hook
        #'(lambda ()
            (goto-char (point-min))
-           (emacspeak-eww-next-h1  'speak)))      
+           (emacspeak-eww-next-h)
+           (dtk-stop)
+           (emacspeak-eww-next-h)
+           (emacspeak-speak-windowful))
+       'at-end)      
       (emacspeak-we-extract-by-id-list
        ems--websearch-google-filter
        search-url)))))
@@ -386,9 +358,11 @@ Optional prefix arg prompts for toolbelt options."
    (list
     (gweb-google-autocomplete "AGoogle: ")
     current-prefix-arg))
-  (cl-declare (special emacspeak-eww-masquerade
-                       ems--websearch-google-filter
-                       emacspeak-websearch-accessible-google-url emacspeak-google-toolbelt))
+  (cl-declare (special
+               emacspeak-eww-masquerade
+               ems--websearch-google-filter
+               emacspeak-websearch-accessible-google-url
+               emacspeak-google-toolbelt))
   (setq emacspeak-google-toolbelt nil)
   (let ((emacspeak-eww-masquerade t)
         (toolbelt (emacspeak-google-toolbelt)))
@@ -401,7 +375,11 @@ Optional prefix arg prompts for toolbelt options."
        'emacspeak-eww-post-process-hook
        #'(lambda ()
            (goto-char (point-min))
-           (emacspeak-eww-next-h1  'speak)))
+           (emacspeak-eww-next-h) (search-forward "Search Tools" nil
+                                                  t)
+           (dtk-stop)
+           (emacspeak-eww-next-h)
+           (emacspeak-speak-windowful)))
       (emacspeak-we-extract-by-id-list
        ems--websearch-google-filter
        (format emacspeak-websearch-accessible-google-url query))))))
@@ -425,8 +403,11 @@ Optional prefix arg prompts for toolbelt options."
   (cl-declare (special calendar-mark-ring))
   (let ((query (emacspeak-websearch-read-query "Google for: "))
         (from (read (calendar-astro-date-string (calendar-cursor-to-date t))))
-        (to (read (calendar-astro-date-string (or (car calendar-mark-ring)
-                                                  (error "No mark set in this buffer"))))))
+        (to
+         (read
+          (calendar-astro-date-string
+           (or (car calendar-mark-ring)
+               (error "No mark set"))))))
     (emacspeak-websearch-google
      (concat
       (url-hexify-string query)
@@ -439,8 +420,7 @@ Optional prefix arg prompts for toolbelt options."
   (define-key calendar-mode-map "gg"
               'emacspeak-websearch-google-search-in-date-range))
 
-;;}}}
-;;{{{ Google News
+;;;  Google News
 
 (emacspeak-websearch-set-searcher 'google-news
                                   'emacspeak-websearch-google-news)
@@ -454,8 +434,7 @@ Optional prefix arg prompts for toolbelt options."
     (emacspeak-url-template-open
      (emacspeak-url-template-get name))))
 
-;;}}}
-;;{{{  Ask Jeeves
+;;;   Ask Jeeves
 
 (emacspeak-websearch-set-searcher 'jeeves
                                   'emacspeak-websearch-ask-jeeves)
@@ -475,8 +454,7 @@ Optional prefix arg prompts for toolbelt options."
            (url-hexify-string query)))
   (emacspeak-websearch-post-process query 'emacspeak-speak-line))
 
-;;}}}
-;;{{{ Merriam Webster
+;;;  Merriam Webster
 
 (emacspeak-websearch-set-searcher 'merriam-webster
                                   'emacspeak-websearch-merriam-webster-search)
@@ -497,8 +475,7 @@ Optional prefix arg prompts for toolbelt options."
    (concat emacspeak-websearch-merriam-webster-uri
            (url-hexify-string query))))
 
-;;}}}
-;;{{{ wikipedia
+;;;  wikipedia
 
 (emacspeak-websearch-set-searcher 'wikipedia
                                   'emacspeak-websearch-wikipedia-search)
@@ -506,14 +483,14 @@ Optional prefix arg prompts for toolbelt options."
 (emacspeak-websearch-set-key ?w 'wikipedia)
 
 (defun emacspeak-websearch-wikipedia-search (query)
-  "Search Wikipedia using Google."
+  "Search Wikipedia using Google.
+Use URL Template `wikipedia at point' to advantage in the results buffer."
   (interactive
    (list (emacspeak-websearch-read-query "Search Wikipedia: ")))
   (emacspeak-websearch-google
    (url-hexify-string (format "site:wikipedia.org %s"query))))
 
-;;}}}
-;;{{{ YouTube Search:
+;;;  YouTube Search:
 
 (emacspeak-websearch-set-searcher 'youtube-search
                                   'emacspeak-websearch-youtube-search)
@@ -526,8 +503,7 @@ Optional prefix arg prompts for toolbelt options."
   (emacspeak-websearch-google
    (url-hexify-string (format "site:youtube.com  %s"query))))
 
-;;}}}
-;;{{{ Shopping at Amazon
+;;;  Shopping at Amazon
 
 (emacspeak-websearch-set-searcher 'amazon-search
                                   'emacspeak-websearch-amazon-search)
@@ -544,12 +520,6 @@ Optional prefix arg prompts for toolbelt options."
   (cl-declare (special emacspeak-websearch-amazon-search-form))
   (browse-url emacspeak-websearch-amazon-search-form))
 
-;;}}}
 (provide 'emacspeak-websearch)
-;;{{{ end of file
+;;;  end of file
 
-;; local variables:
-;; folded-file: t
-;; end:
-
-;;}}}
