@@ -3,19 +3,18 @@
 ;; $Author: tv.raman.tv $
 ;; Description:  Speech-enable XKCD An Emacs Interface to xkcd
 ;; Keywords: Emacspeak,  Audio Desktop xkcd
-;;{{{  LCD Archive entry:
+;;;   LCD Archive entry:
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
 ;; 
 ;;  $Revision: 4532 $ |
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
-;; Copyright (C) 1995 -- 2022, T. V. Raman
+;;;   Copyright:
+;; Copyright (C) 1995 -- 2024, T. V. Raman
 ;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;; All Rights Reserved.
 ;; 
@@ -33,12 +32,11 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  introduction
 
 ;;; Commentary:
 ;; XKCD ==  XKCD In Emacs
@@ -46,16 +44,16 @@
 ;; Speech enables package xkcd
 ;; Augments it by displaying the alt text and the transcript.
 
-;;}}}
-;;{{{  Required modules
+;;   Required modules:
+;;; Code:
 
-(require 'cl-lib)
+(eval-when-compile (require 'cl-lib))
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'json)
 (require 'xkcd "xkcd" 'no-error)
-;;}}}
-;;{{{ Fix error when loading images on the console:
+
+;;;  Fix error when loading images on the console:
 
 (defadvice xkcd-insert-image (around emacspeak pre act comp)
   "no-Op on console"
@@ -63,12 +61,10 @@
    ((not window-system) t)
    (t ad-do-it)))
 
-;;}}}
-
 (defadvice xkcd-kill-buffer (after emacspeak pre act comp)
   "speak."
   (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'close-object)
+    (emacspeak-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defvar xkcd-transcript nil
@@ -96,16 +92,15 @@
                  "Not available yet."
                xkcd-transcript)))
     (goto-char (point-min))
-    (emacspeak-auditory-icon 'open-object)
+    (emacspeak-icon 'open-object)
     (emacspeak-speak-buffer)))
-;;{{{ Advice browse-url-default-browser:
+;;;  Advice browse-url-default-browser:
 
 (defadvice browse-url-default-browser (around emacspeak pre act comp)
   "Use Emacs browser --- rather than an external browser."
   (when nil ad-do-it) ; to silence byte-compiler 
   (eww-browse-url (ad-get-arg 0)))
 
-;;}}}
 (defun emacspeak-xkcd-open-explanation-browser ()
   "Open explanation of current xkcd in default browser"
   (interactive)
@@ -115,10 +110,5 @@
 (when (boundp 'xkcd-mode-map)
   (define-key xkcd-mode-map "e" 'emacspeak-xkcd-open-explanation-browser))
 (provide 'emacspeak-xkcd)
-;;{{{ end of file
+;;;  end of file
 
-;; local variables:
-;; folded-file: t
-;; end:
-
-;;}}}
