@@ -1,17 +1,16 @@
-;;; extra-muggles.el --- Additional Hydras For The Emacspeak Desktop  -*- lexical-binding: t; -*-
+;;; extra-muggles.el --- Additional Hydras -*- lexical-binding: t; -*-
 ;; $Author: tv.raman.tv $
 ;; Description:  Speech-enable MUGGLES An Emacs Interface to muggles
 ;; Keywords: Emacspeak,  Audio Desktop muggles
-;;{{{  LCD Archive entry:
+;;;   LCD Archive entry:
 
 ;; LCD Archive Entry:
 ;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;; A speech interface to Emacs |
-;; Location undetermined
+;; Location https://github.com/tvraman/emacspeak
 ;; 
 
-;;}}}
-;;{{{  Copyright:
+;;;   Copyright:
 
 ;; Copyright (C) 1995 -- 2007, 2011, T. V. Raman
 ;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
@@ -31,12 +30,11 @@
 ;; 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
-;;}}}
 ;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  introduction
 
 ;;; Commentary:
 
@@ -63,6 +61,7 @@
 ;; @subsection Extra Muggles
 
 ;; @itemize
+;; @item  org-mode structure nav: @kbd{C-c C-SPC}  Navigation  for org-mode.
 ;; @item View-Mode: @kbd{C-. v} Temporarily behave like view-mode.
 ;; @item SmartParens: @kbd{C-c ,} Smart Parens
 ;; @item m-player: @kbd{s-m} Emacspeak-M-Player Commands
@@ -82,35 +81,35 @@
 
 ;;; Code:
 
-;;}}}
-;;{{{  Required modules
+;;   Required modules:
 
-(require 'cl-lib)
+(eval-when-compile (require 'cl-lib))
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'emacspeak-dired)
+(require 'hydra)
+(require 'emacspeak-hydra)
+(require 'org)
+(require 'emacspeak-outline)
+(require 'emacspeak-m-player)
+(require 'view)
+(require 'smartparens "smartparens" 'no-error)
 (eval-when-compile
-  ;; FIXME: Network access as part of compilation is EVIL!
-  ;; (when (locate-library "package")
-  ;;   (unless (locate-library "hydra") (package-install 'hydra)))
+  (setq byte-compile-warnings '(not docstrings))
   (require 'emacspeak-hydra)
-  (require 'emacspeak-outline)
+  
   (require 'vuiet nil 'no-error)
-  (require 'smartparens "smartparens" 'no-error)
-  (require 'hydra "hydra" 'no-error)
-  (require 'view)
-  (require 'emacspeak-m-player))
+  (require 'hydra "hydra" 'no-error))
+(require 'eww)
 (with-no-warnings (require 'origami "origami" 'no-error))
 
-;;}}}
-;;{{{ Generate Muggles From Keymaps:
+;;;  Generate Muggles From Keymaps:
 
-;; Generate A Muggle:
-;; Take a name of a keymap (symbol)
-;; And generate an interactive command that can be bound to a key.
-;; Invoking that command temporarily activates the previously supplied keymap.
-;; That activated keymap remains active until the user presses a key that is not bound in that keymap.
-;; Inspired by the Hydra package.
+;; Generate A Muggle: Take a name of a keymap (symbol) And generate an
+;; interactive command that can be bound to a key.  Invoking that
+;; command temporarily activates the previously supplied keymap.  That
+;; activated keymap remains active until the user presses a key that
+;; is not bound in that keymap.  Inspired by the Hydra package.
 
 (defun emacspeak-muggles-generate (k-map)
   "Generate a Muggle from specified k-map.
@@ -130,26 +129,25 @@ Argument `k-map' is a symbol  that names a keymap."
             (setq key (read-key-sequence "Key: ")
                   cmd (lookup-key ,k-map key)))
           (call-interactively (lookup-key (current-global-map) key))
-          (emacspeak-auditory-icon 'close-object))))))
+          (emacspeak-icon 'close-object))))))
 
 ;; Create a command to invoke our media player map:
 
 (global-set-key
- (ems-kbd "s-m")
+ (kbd "s-m")
  (emacspeak-muggles-generate 'emacspeak-m-player-mode-map))
 
 ;; Create one for pianobar
 (when (featurep 'pianobar)
   (global-set-key
-   (ems-kbd "s-'")
+   (kbd "s-'")
    (emacspeak-muggles-generate 'pianobar-key-map)))
 
-;;}}}
-;;{{{ Media Player:
+;;;  Media Player:
 
 (declare-function emacspeak-amark-save "emacspeak-muggles" t)
 (global-set-key
- (ems-kbd "s-;")
+ (kbd "s-;")
  (defhydra emacspeak-muggles-m-player
            (:body-pre (emacspeak-hydra-body-pre "Media Player")
                       :pre emacspeak-hydra-pre :post emacspeak-hydra-post)
@@ -161,8 +159,6 @@ Argument `k-map' is a symbol  that names a keymap."
            ("." emacspeak-m-player-forward-10s)
            ("<" emacspeak-m-player-backward-1min)
            ("<down>" emacspeak-m-player-forward-1min)
-           ("<end>" emacspeak-m-player-end-of-track)
-           ("<home>" emacspeak-m-player-beginning-of-track)
            ("<left>" emacspeak-m-player-backward-10s)
            ("<next>" emacspeak-m-player-forward-10min)
            ("<prior>" emacspeak-m-player-backward-10min)
@@ -170,13 +166,8 @@ Argument `k-map' is a symbol  that names a keymap."
            ("<up>" emacspeak-m-player-backward-1min)
            ("=" emacspeak-m-player-volume-up)
            (">" emacspeak-m-player-forward-1min)
-           ("?" emacspeak-m-player-display-position)
            ("C" emacspeak-m-player-clear-filters)
-           ("C-m" emacspeak-m-player-load)
            ("DEL" emacspeak-m-player-reset-speed)
-           ("M-l" emacspeak-m-player-load-playlist)
-           ("O" emacspeak-m-player-reset-options)
-           ("P" emacspeak-m-player-apply-reverb-preset)
            ("Q" emacspeak-m-player-quit "quit")
            ("R" emacspeak-m-player-edit-reverb)
            ("S" emacspeak-amark-save)
@@ -194,12 +185,10 @@ Argument `k-map' is a symbol  that names a keymap."
            ("l" emacspeak-m-player-get-length)
            ("m" emacspeak-m-player-mode-line)
            ("n" emacspeak-m-player-next-track)
-           ("o" emacspeak-m-player-customize-options)
            ("p" emacspeak-m-player-previous-track)
            ("q" bury-buffer)
            ("r" emacspeak-m-player-seek-relative)
            ("s" emacspeak-m-player-scale-speed)
-           ("t" emacspeak-m-player-play-tracks-jump)
            ("u" emacspeak-m-player-url)
            ("v" emacspeak-m-player-volume-change)
            ("(" emacspeak-m-player-left-channel)
@@ -208,12 +197,11 @@ Argument `k-map' is a symbol  that names a keymap."
            ("}" emacspeak-m-player-double-speed)
            ))
 
-;;}}}
-;;{{{ Outliner:
+;;;  Outliner:
 
 ;; Cloned from Hydra Wiki:
 (global-set-key
- (ems-kbd "C-. o")
+ (kbd "C-. o")
  (defhydra emacspeak-muggles-outliner
            (:body-pre
             (progn
@@ -234,18 +222,18 @@ _d_: subtree
 "
            ("?" (emacspeak-hydra-self-help "emacspeak-muggles-outliner"))
            ;; Hide
-           ("q" outline-hide-sublevels) ; Hide everything but the top-level headings
-           ("t" outline-hide-body) ; Hide everything but headings (all body lines)
+           ("q" outline-hide-sublevels)
+           ("t" outline-hide-body)
            ("o" outline-hide-other)             ; Hide other branches
            ("c" outline-hide-entry)             ; Hide this entry's body
-           ("l" outline-hide-leaves) ; Hide body lines in this entry and sub-entries
-           ("d" outline-hide-subtree) ; Hide everything in this entry and sub-entries
+           ("l" outline-hide-leaves)
+           ("d" outline-hide-subtree)
            ;; Show
            ("a" outline-show-all)               ; Show (expand) everything
            ("e" outline-show-entry)             ; Show this heading's body
-           ("i" outline-show-children) ; Show this heading's immediate child sub-headings
-           ("k" outline-show-branches) ; Show all sub-headings under this heading
-           ("s" outline-show-subtree) ; Show (expand) everything in this heading & below
+           ("i" outline-show-children) 
+           ("k" outline-show-branches)
+           ("s" outline-show-subtree)
            ;; Move
            ("u" outline-up-heading)               ; Up
            ("n" outline-next-visible-heading)     ; Next
@@ -254,27 +242,18 @@ _d_: subtree
            ("b" outline-backward-same-level)      ; Backward - same level
            ("z" nil "leave")))
 
-;;}}}
-;;{{{ Info Summary:
+;;;  Info Summary:
 
 ;; Taken from Hydra wiki and customized to taste:
-(define-key Info-mode-map (ems-kbd "?")
+(define-key Info-mode-map (kbd "?")
             (defhydra emacspeak-muggles-info-summary
-                      (:color blue :hint nil
-                              :body-pre (emacspeak-hydra-body-pre "Info Summary")
-                              :pre emacspeak-hydra-pre :post emacspeak-hydra-post)
-                      "
-Info-mode:
-
-  ^^_]_ forward  (next logical node)       ^^_l_ast (←)        _u_p (↑)                             _f_ollow reference       _T_OC
-  ^^_[_ backward (prev logical node)       ^^_r_eturn (→)      _m_enu (↓) (C-u for new window)      _i_ndex                  _d_irectory
-  ^^_n_ext (same level only)               ^^_H_istory         _g_oto (C-u for new window)          _,_ next index item      _c_opy node name
-  ^^_p_rev (same level only)               _<_/_t_op           _b_eginning of buffer                virtual _I_ndex          _C_lone buffer
-  regex _s_earch (_S_ case sensitive)      ^^_>_ final         _e_nd of buffer                      ^^                       _a_propos
-
-  _1_ .. _9_ Pick first .. ninth item in the node's menu.
-
-"
+                      (
+                       :color blue :hint nil
+                       :body-pre (emacspeak-hydra-body-pre "Info Summary")
+                       :pre
+                       emacspeak-hydra-pre
+                       :post emacspeak-hydra-post)
+                      "info mode"
                       ("]"   Info-forward-node)
                       ("["   Info-backward-node)
                       ("n"   Info-next)
@@ -322,8 +301,7 @@ Info-mode:
                       ("q"   quit-window "Info exit")
                       ("C-g" nil "cancel" :color blue)))
 
-;;}}}
-;;{{{ origami:
+;;;  origami:
 
 (declare-function origami-open-node "origami" (buffer point))
 (declare-function origami-close-node "origami" (buffer point))
@@ -334,7 +312,7 @@ Info-mode:
 (declare-function origami-mode "origami" (&optional arg))
 
 (global-set-key
- (ems-kbd "C-, /")
+ (kbd "C-, /")
  (defhydra emacspeak-origami
            (:color red
                    :body-pre
@@ -355,8 +333,7 @@ Info-mode:
            ("f" origami-forward-toggle-node)
            ("a" origami-toggle-all-nodes)))
 
-;;}}}
-;;{{{ Muggles Autoload Wizard:
+;;;  Muggles Autoload Wizard:
 
 (defvar emacspeak-muggles-pattern
   "emacspeak-muggles-.*/body$"
@@ -390,18 +367,18 @@ Also generates global keybindings if any."
       (cl-loop
        for m in muggles do
        (let ((key  (where-is-internal m nil 'first)))
-         (insert (format "(autoload '%s \"emacspeak-muggles\" \"%s\" t)\n" m m))
+         (insert
+          (format "(autoload '%s \"emacspeak-muggles\" \"%s\" t)\n" m m))
          (when key 
            (insert (format "(global-set-key %s '%s)\n" key m)))))
       (insert "\n(provide 'emacspeak-muggles-autoloads)\n")
       (save-buffer))
     (message "Generated autoloads for muggles.")))
 
-;;}}}
-;;{{{ smartParens:
+;;;  smartParens:
 
 (global-set-key
- (ems-kbd "C-c ,")
+ (kbd "C-c ,")
  (defhydra emacspeak-muggles-smartparens
            (:body-pre
             (progn
@@ -439,11 +416,10 @@ Also generates global keybindings if any."
            ("w" sp-copy-sexp)  
            ("{" #'(lambda (_) (interactive "P") (sp-wrap-with-pair "{")))))
 
-;;}}}
-;;{{{  View Mode:
+;;;   View Mode:
 
 (global-set-key
- (ems-kbd
+ (kbd
   "C-. v")
  (defhydra emacspeak-muggles-view
            (:body-pre
@@ -501,14 +477,13 @@ Also generates global keybindings if any."
            ("}" forward-paragraph)
            ))
 
-;;}}}
-;;{{{Vuiet:
+;;; Vuiet:
 
 (declare-function emacspeak-vuiet-track-info "emacspeak-vuiet" nil)
 (when (locate-library "vuiet")
   (with-no-warnings
     (global-set-key
-     (ems-kbd "C-; v")
+     (kbd "C-; v")
      (defhydra emacspeak-muggles-vuiet
                (:body-pre
                 (progn
@@ -535,13 +510,33 @@ Also generates global keybindings if any."
                ("t" vuiet-play-track)
                ("u" vuiet-unlove-track)))))
 
-;;}}}
+;;;  Org Mode Structure Navigation:
+
+(with-eval-after-load "org"
+  (cl-declaim (special org-mode-map))
+  (define-key
+   org-mode-map
+   (kbd "C-c C-SPC")
+   (defhydra emacspeak-muggles-org-nav
+             (:body-pre
+              (progn
+                (emacspeak-hydra-toggle-talkative)
+                (emacspeak-hydra-body-pre "OrgNavView"))
+              :hint nil
+              :pre emacspeak-hydra-pre :post emacspeak-hydra-post
+              :color red :columns 3)
+             "Org Mode Navigate "
+             ("?" (emacspeak-hydra-self-help "emacspeak-muggles-org-nav"))
+             ("SPC" emacspeak-outline-speak-this-heading  "Speak this section")
+             ("n" emacspeak-outline-speak-next-heading  "next heading")
+             ("p" emacspeak-outline-speak-previous-heading "prev heading")
+             ("f" org-forward-heading-same-level "next heading at same level")
+             ("b" org-backward-heading-same-level "prev heading at same level")
+             ("u" outline-up-heading "up heading")
+             ("g" org-goto "goto" :exit t))))
+
 (provide 'extra-muggles)
-;;{{{ end of file
+;;;  end of file
 
-;; local variables:
-;; folded-file: t
 ;; byte-compile-warnings: (docstring noruntime )
-;; end:
 
-;;}}}
